@@ -61,14 +61,14 @@ define('io.ox/backbone/mini-views/date', [
         }
 
         // add empty option - do that after revert
-        empty = $('<option>', { value: name === 'year' ? '0001' : '' }).text('');
+        empty = $('<option>', { value: name === 'year' ? '1604' : '' }).text('');
         options.unshift(empty);
 
         // append
         return node.append(options);
     }
 
-    var DateView = AbstractView.extend({
+    var DateSelectView = AbstractView.extend({
 
         className: 'native-date-picker row',
         events: { 'change select': 'onChange' },
@@ -80,8 +80,7 @@ define('io.ox/backbone/mini-views/date', [
                 if (!d.isValid()) {
                     // jump back to last valid day of previous month
                     // invalid date cannot be fixed by changing days. use valid date before change month
-                    d = moment(d.valueOf());
-                    d.date(0);
+                    d = moment([d.creationData().input.year, d.creationData().input.month]).endOf('month').hours(1).minutes(0).seconds(0).milliseconds(0);
                     // set date field to right day
                     // needs to be done or an invalid date can be selected
                     // if model already has the corrected date
@@ -123,7 +122,7 @@ define('io.ox/backbone/mini-views/date', [
             if (_.isNumber(value)) {
                 d = moment.utc(value);
                 year = String(d.year());
-                if (year !== '1') {
+                if (year !== '1' && year !== '1604') {
                     // if the year is not our dropdown we add it
                     var yearValues = [];
                     this.$el.find('.year option').each(function () {
@@ -136,6 +135,9 @@ define('io.ox/backbone/mini-views/date', [
                         );
                     }
                 }
+                // 1604 is the new date without year see bug 56075
+                if (year === '1') year = 1604;
+
                 this.$el.find('.year').val(_.pad(year, 4));
                 this.$el.find('.month').val(d.month());
                 this.$el.find('.date').val(d.date());
@@ -187,6 +189,6 @@ define('io.ox/backbone/mini-views/date', [
     });
 
     return {
-        DateView: DateView
+        DateSelectView: DateSelectView
     };
 });
