@@ -20,10 +20,10 @@ define('io.ox/calendar/actions', [
     'io.ox/core/print',
     'gettext!io.ox/calendar',
     'io.ox/core/capabilities',
-    'io.ox/calendar/actions/change-confirmation',
     'io.ox/core/folder/api',
-    'io.ox/core/yell'
-], function (ext, links, api, util, actions, print, gt, capabilities, changeStatus, folderAPI, yell) {
+    'io.ox/core/yell',
+    'settings!io.ox/calendar'
+], function (ext, links, api, util, actions, print, gt, capabilities, folderAPI, yell, settings) {
 
     'use strict';
 
@@ -33,7 +33,7 @@ define('io.ox/calendar/actions', [
     new Action('io.ox/calendar/actions/switch-to-list-view', {
         requires: true,
         action: function (baton) {
-            ox.ui.Perspective.show(baton.app, 'list');
+            baton.app.pages.changePage('list', { disableAnimations: true });
         }
     });
 
@@ -42,7 +42,7 @@ define('io.ox/calendar/actions', [
             return true;
         },
         action: function (baton) {
-            ox.ui.Perspective.show(baton.app, 'month');
+            baton.app.pages.changePage('month', { disableAnimations: true });
         }
     });
 
@@ -51,7 +51,7 @@ define('io.ox/calendar/actions', [
             return _.device('!smartphone');
         },
         action: function (baton) {
-            ox.ui.Perspective.show(baton.app, 'week:week');
+            baton.app.pages.changePage(baton.app, 'week:week');
         }
     });
 
@@ -60,24 +60,24 @@ define('io.ox/calendar/actions', [
             return _.device('!smartphone');
         },
         action: function (baton) {
-            ox.ui.Perspective.show(baton.app, 'week:workweek');
+            baton.app.pages.changePage(baton.app, 'week:workweek');
         }
     });
 
     new Action('io.ox/calendar/actions/switch-to-day-view', {
         requires: true,
         action: function (baton) {
-            ox.ui.Perspective.show(baton.app, 'week:day');
+            baton.app.pages.changePage(baton.app, 'week:day');
         }
     });
 
     new Action('io.ox/calendar/detail/actions/sendmail', {
         capabilities: 'webmail',
         requires: function (e) {
-            return e.baton.model && e.baton.model.has('attendees') && e.baton.model.get('attendees').length > 1;
+            return e.baton.model && e.baton.model.has('attendees');
         },
         action: function (baton) {
-            util.resolveParticipants(baton.data, { filterSelf: true }).done(function (recipients) {
+            util.resolveParticipants(baton.data).done(function (recipients) {
                 var hash = {};
                 recipients = _(recipients)
                     .chain()
@@ -85,6 +85,12 @@ define('io.ox/calendar/actions', [
                         // don't add duplicates
                         return rec.mail in hash ? false : (hash[rec.mail] = true);
                     })
+                    .filter(function (rec) {
+                        // don't add myself
+                        // don't add if mail address is missing (yep, edge-case)
+                        // support user and contact data
+                        return rec.id !== ox.user_id && rec.internal_userid !== ox.user_id && !!rec.mail;
+                    })
                     .map(function (rec) {
                         return [rec.display_name, rec.mail];
                     })
@@ -97,7 +103,7 @@ define('io.ox/calendar/actions', [
     new Action('io.ox/calendar/detail/actions/invite', {
         capabilities: 'calendar',
         requires: function (e) {
-            return e.baton.model && e.baton.model.has('attendees') && e.baton.model.get('attendees').length > 1 && !capabilities.has('guest');
+            return e.baton.model && e.baton.model.has('attendees') && !capabilities.has('guest');
         },
         action: function (baton) {
             ox.load(['io.ox/calendar/actions/invite']).done(function (action) {
@@ -143,7 +149,7 @@ define('io.ox/calendar/actions', [
 
     new Action('io.ox/calendar/detail/actions/delete', {
         requires: function (e) {
-            return e.collection.has('delete') && ((util.hasFlag(e.baton.data, 'organizer') || util.hasFlag(e.baton.data, 'attendee')));
+            return e.collection.has('delete') && ((util.hasFlag(e.baton.data, 'organizer') || util.hasFlag(e.baton.data, 'organizer_on_behalf') || util.hasFlag(e.baton.data, 'attendee') || util.hasFlag(e.baton.data, 'attendee_on_behalf')));
         },
         multiple: function (list) {
             ox.load(['io.ox/calendar/actions/delete']).done(function (action) {
@@ -163,16 +169,11 @@ define('io.ox/calendar/actions', [
         }
     });
 
-    new Action('io.ox/calendar/detail/actions/changestatus', {
+    new Action('io.ox/calendar/detail/actions/changeAlarms', {
         requires: function (e) {
             function cont(model, folderData) {
-
-                // in shared calendars the attendee means the calendar owner is attendee, we have to look if we have modify permission
-                if (folderAPI.is('shared', folderData)) {
-                    return e.collection.has('one', 'modify') && util.hasFlag(model, 'attendee');
-                }
-
-                return e.collection.has('one') && util.hasFlag(model, 'attendee');
+                // folder must support alarms. We don't show the action if the attendee flag is present (change status is shown instead). We only offer this for the birthday calendar for now
+                return e.collection.has('one') && !(util.hasFlag(model, 'attendee') || util.hasFlag(model, 'attendee_on_behalf')) && folderData['com.openexchange.calendar.provider'] === 'birthdays' && folderData.supported_capabilities.indexOf('alarms') !== -1;
             }
 
             var model = e.baton.model,
@@ -184,14 +185,55 @@ define('io.ox/calendar/actions', [
 
             // incomplete
             if (data && !model) {
-                return $.when(api.get(data), folderAPI.get(data.folder)).then(cont);
+                return $.when(api.get(data), folderAPI.get(data.folder)).then(cont, function () { return false; });
             }
-            return $.when(model, folderAPI.get(data.folder)).then(cont);
+            return $.when(model, folderAPI.get(data.folder)).then(cont, function () { return false; });
+        },
+        action: function (baton) {
+            // load & call
+            ox.load(['io.ox/calendar/actions/change-alarms']).done(function (action) {
+                action(baton.data);
+            });
+        }
+    });
+
+    new Action('io.ox/calendar/detail/actions/changestatus', {
+        requires: function (e) {
+            function cont(model) {
+                //no flags at all => public folder and user is no attendee. Not allowed to change attendee statuses
+                if (!util.hasFlag(model, 'accepted') && !util.hasFlag(model, 'declined') &&
+                    !util.hasFlag(model, 'tentative') && !util.hasFlag(model, 'needs_action')) return false;
+
+                // in shared calendars the attendee means the calendar owner is attendee, we have to look if we have modify permission
+                if (util.hasFlag(model, 'attendee_on_behalf') || util.hasFlag(model, 'organizer_on_behalf') && !(util.hasFlag(model, 'attendee') || util.hasFlag(model, 'organizer'))) {
+                    return e.collection.has('one', 'modify');
+                }
+
+                return e.collection.has('one') && (util.hasFlag(model, 'attendee') || util.hasFlag(model, 'organizer'));
+            }
+
+            var model = e.baton.model,
+                data = e.baton.data;
+
+            // cannot confirm appointments without proper id (happens when detail view was opened from mail invitation from external calendar)
+            // must use buttons in invitation mail instead
+            if (!data.id) return false;
+
+            // incomplete
+            if (data && !model) {
+                return $.when(api.get(data)).then(cont, function () { return false; });
+            }
+            return $.when(model).then(cont, function () { return false; });
         },
         action: function (baton) {
             // load & call
             ox.load(['io.ox/calendar/actions/acceptdeny']).done(function (action) {
-                action(baton.data, { noFolderCheck: baton.noFolderCheck });
+                // get full data if possible
+                api.get(baton.data).then(function (obj) {
+                    action(obj.toJSON(), { noFolderCheck: baton.noFolderCheck });
+                }, function () {
+                    action(baton.data, { noFolderCheck: baton.noFolderCheck });
+                });
             });
         }
     });
@@ -244,8 +286,8 @@ define('io.ox/calendar/actions', [
     new Action('io.ox/calendar/detail/actions/export', {
         requires: 'some read',
         action: function (baton) {
-            require(['io.ox/core/export'], function (exportDialog) {
-                exportDialog.open('calendar', { list: [].concat(baton.data) });
+            require(['io.ox/core/download'], function (download) {
+                download.exported({ list: [].concat(baton.data), format: 'ical' });
             });
         }
     });
@@ -263,17 +305,8 @@ define('io.ox/calendar/actions', [
 
     new Action('io.ox/calendar/detail/actions/print', {
         capabilities: 'calendar-printing',
-        requires: function (e) {
-            var win = e.baton.window;
-            if (_.device('!smartphone') && win && win.getPerspective) {
-                var pers = win.getPerspective();
-                return pers && pers.print;
-            }
-            return false;
-        },
         action: function (baton) {
-            var win = baton.app.getWindow(),
-                pers = win.getPerspective();
+            var pers = baton.app.perspective;
             if (pers.print) {
                 pers.print();
             }
@@ -290,27 +323,55 @@ define('io.ox/calendar/actions', [
                     if (!isSeries) isSeries = !!item.recurrenceId;
                 });
             }
-            return e.collection.has('some', 'delete') && util.hasFlag(e.baton.data, 'organizer') && !isSeries;
+            return e.collection.has('some', 'delete') && !isSeries;
         },
         multiple: function (list, baton) {
             ox.load(['io.ox/core/folder/actions/move', 'settings!io.ox/calendar']).done(function (move, settings) {
-                move.item({
-                    api: api,
-                    button: gt('Move'),
-                    flat: true,
-                    indent: false,
-                    list: list,
-                    module: 'calendar',
-                    root: '1',
-                    settings: settings,
-                    success: {
-                        single: 'Appointment has been moved',
-                        multiple: 'Appointments have been moved'
-                    },
-                    target: baton.target,
-                    title: gt('Move'),
-                    type: 'move',
-                    all: util.getCurrentRangeOptions()
+                folderAPI.get(list[0].folder).done(function (folderData) {
+
+                    // maybe we need a whoAmI util function ...
+                    var myId;
+                    // acting myself
+                    if (util.hasFlag(list[0], 'attendee') || util.hasFlag(list[0], 'organizer')) {
+                        myId = ox.user_id;
+                    // action on behalf of attendee
+                    } else if (util.hasFlag(list[0], 'attendee_on_behalf')) {
+                        myId = folderData.created_by;
+                    // action on behalf of organizer
+                    } else if (util.hasFlag(list[0], 'organizer_on_behalf')) {
+                        myId = list[0].organizer.entity;
+                    }
+
+                    move.item({
+                        api: api,
+                        button: gt('Move'),
+                        flat: true,
+                        indent: false,
+                        list: list,
+                        module: 'calendar',
+                        root: '1',
+                        settings: settings,
+                        success: {
+                            single: 'Appointment has been moved',
+                            multiple: 'Appointments have been moved'
+                        },
+                        target: baton.target,
+                        title: gt('Move'),
+                        type: 'move',
+                        all: util.getCurrentRangeOptions(),
+                        disable: function (data, options) {
+                            var sameFolder = data.id === list[0].folder,
+                                sameOwner = data.created_by === myId,
+                                isPublic = folderAPI.is('public', data),
+                                sourceFolderIsPublic = folderAPI.is('public', folderData),
+                                noOtherAttendees = list[0].attendees.length < 2,
+                                create = folderAPI.can('create', data);
+
+                            // totally awesome check
+                            // not same folder, must be folder of same user, public folder or there must only be one attendee(the organizer), if the source folder is not public, must have create permission in that folder, folder must not be virtual
+                            return sameFolder || !((!sourceFolderIsPublic && noOtherAttendees) || sameOwner || isPublic) || !create || (options && /^virtual/.test(options.folder));
+                        }
+                    });
                 });
             });
         }
@@ -318,16 +379,14 @@ define('io.ox/calendar/actions', [
 
     new Action('io.ox/calendar/actions/today', {
         requires: function (baton) {
-            var p = baton.baton.app.getWindow().getPerspective();
-
-            return !!p && (p.name === 'month' || p.name === 'week');
+            var p = baton.baton.app.perspective;
+            return !!p && (p.getName() === 'month' || p.getName() === 'week');
         },
         action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
+            var p = baton.app.perspective;
 
-            if (p.view && p.view.setStartDate) {
-                p.view.setStartDate();
-                p.view.trigger('onRefresh');
+            if (p.setStartDate) {
+                p.setStartDate();
             } else if (p.gotoMonth) {
                 p.gotoMonth('today');
             }
@@ -342,15 +401,15 @@ define('io.ox/calendar/actions', [
         action: function (baton) {
             require(['io.ox/calendar/freetime/main', 'io.ox/core/api/user'], function (freetime, userAPI) {
                 userAPI.get().done(function (user) {
-                    var perspective = baton.app.getWindow().getPerspective(),
+                    var perspective = baton.app.perspective,
                         now = _.now(),
-                        startDate = perspective && perspective.name !== 'month' && perspective.getStartDate ? perspective.getStartDate() : now,
+                        startDate = perspective && perspective.model && perspective.model.get('date') ? perspective.model.get('date').valueOf() : now,
                         layout = perspective ? perspective.app.props.get('layout') : '';
 
                     // see if the current day is in the displayed week.
                     if (startDate < now && layout.indexOf('week:') === 0) {
                         // calculate end of week/workweek
-                        var max = startDate + 86400000 * (layout === 'week:workweek' ? 5 : 7);
+                        var max = startDate + 86400000 * (layout === 'week:workweek' ? settings.get('numDaysWorkweek') : 7);
                         if (now < max) {
                             startDate = now;
                         }
@@ -363,60 +422,30 @@ define('io.ox/calendar/actions', [
     });
 
     // Actions mobile
-    new Action('io.ox/calendar/actions/monthview/showNext', {
+    new Action('io.ox/calendar/actions/showNext', {
         requires: true,
         action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
+            var p = baton.app.perspective;
             if (!p) return;
-            p.gotoMonth('next');
+            p.setStartDate('next');
         }
     });
 
-    new Action('io.ox/calendar/actions/monthview/showPrevious', {
+    new Action('io.ox/calendar/actions/showPrevious', {
         requires: true,
         action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
+            var p = baton.app.perspective;
             if (!p) return;
-            p.gotoMonth('prev');
+            p.setStartDate('prev');
         }
     });
 
-    new Action('io.ox/calendar/actions/dayview/showNext', {
+    new Action('io.ox/calendar/actions/showToday', {
         requires: true,
         action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
+            var p = baton.app.perspective;
             if (!p) return;
-            p.view.setStartDate('next');
-            p.view.trigger('onRefresh');
-        }
-    });
-
-    new Action('io.ox/calendar/actions/dayview/showPrevious', {
-        requires: true,
-        action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
-            if (!p) return;
-            p.view.setStartDate('prev');
-            p.view.trigger('onRefresh');
-        }
-    });
-
-    new Action('io.ox/calendar/actions/dayview/showToday', {
-        requires: true,
-        action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
-            if (!p) return;
-            p.view.setStartDate();
-            p.view.trigger('onRefresh');
-        }
-    });
-
-    new Action('io.ox/calendar/actions/month/showToday', {
-        requires: true,
-        action: function (baton) {
-            var p = baton.app.getWindow().getPerspective();
-            if (!p) return;
-            p.gotoMonth('today');
+            p.setStartDate(moment());
         }
     });
 
@@ -438,11 +467,11 @@ define('io.ox/calendar/actions', [
         var appointment = api.reduce(baton.data),
             def = baton.noFolderCheck ? $.when() : folderAPI.get(appointment.folder);
 
-        def.done(function (folder) {
+        def.always(function (folder) {
 
             appointment.attendee = {
                 // act as folder owner in shared folder
-                entity: !baton.noFolderCheck && folderAPI.is('shared', folder) ? folder.created_by : ox.user_id,
+                entity: !folder.error && !baton.noFolderCheck && folderAPI.is('shared', folder) ? folder.created_by : ox.user_id,
                 partStat: accept ? 'ACCEPTED' : 'DECLINED'
             };
 
@@ -493,20 +522,15 @@ define('io.ox/calendar/actions', [
     new Action('io.ox/calendar/actions/accept-appointment', {
         requires: function (e) {
             if (!e || !e.baton || !e.baton.data || !e.baton.data.flags) return false;
-            if (!(util.hasFlag(e.baton.data, 'attendee') && !util.hasFlag(e.baton.data, 'accepted'))) return false;
-
-            var def = $.Deferred();
-            folderAPI.get(e.baton.data.folder).then(function (folderData) {
-                // in shared folders we also have to check if we have the permissin to modify
-                if (folderAPI.is('shared', folderData)) {
-                    def.resolve(e.collection.has('modify'));
-                }
-                def.resolve(true);
-            }, function () {
-                def.resolve(true);
-            });
-
-            return def;
+            if (util.hasFlag(e.baton.data, 'accepted')) return false;
+            //no flags at all => public folder and user is no attendee. Not allowed to change attendee statuses
+            if (!util.hasFlag(e.baton.data, 'accepted') && !util.hasFlag(e.baton.data, 'declined') &&
+                !util.hasFlag(e.baton.data, 'tentative') && !util.hasFlag(e.baton.data, 'needs_action')) return false;
+            // in shared folders we also have to check if we have the permissin to modify
+            if ((util.hasFlag(e.baton.data, 'attendee_on_behalf') || util.hasFlag(e.baton.data, 'organizer_on_behalf')) &&
+                !(util.hasFlag(e.baton.data, 'attendee') || util.hasFlag(e.baton.data, 'organizer')) &&
+                !e.collection.has('modify')) return false;
+            return true;
         },
         action: _.partial(acceptDecline, _, true)
     });
@@ -514,20 +538,15 @@ define('io.ox/calendar/actions', [
     new Action('io.ox/calendar/actions/decline-appointment', {
         requires: function (e) {
             if (!e || !e.baton || !e.baton.data || !e.baton.data.flags) return false;
-            if (!(util.hasFlag(e.baton.data, 'attendee') && !util.hasFlag(e.baton.data, 'declined'))) return false;
-
-            var def = $.Deferred();
-            folderAPI.get(e.baton.data.folder).then(function (folderData) {
-                // in shared folders we also have to check if we have the permissin to modify
-                if (folderAPI.is('shared', folderData)) {
-                    def.resolve(e.collection.has('modify'));
-                }
-                def.resolve(true);
-            }, function () {
-                def.resolve(true);
-            });
-
-            return def;
+            if (util.hasFlag(e.baton.data, 'declined')) return false;
+            //no flags at all => public folder and user is no attendee. Not allowed to change attendee statuses
+            if (!util.hasFlag(e.baton.data, 'accepted') && !util.hasFlag(e.baton.data, 'declined') &&
+                !util.hasFlag(e.baton.data, 'tentative') && !util.hasFlag(e.baton.data, 'needs_action')) return false;
+            // in shared folders we also have to check if we have the permissin to modify
+            if ((util.hasFlag(e.baton.data, 'attendee_on_behalf') || util.hasFlag(e.baton.data, 'organizer_on_behalf')) &&
+                !(util.hasFlag(e.baton.data, 'attendee') || util.hasFlag(e.baton.data, 'organizer')) &&
+                !e.collection.has('modify')) return false;
+            return true;
         },
         action: acceptDecline
     });
@@ -612,6 +631,16 @@ define('io.ox/calendar/actions', [
         ref: 'io.ox/calendar/detail/actions/changestatus'
     }));
 
+    // 155 because it's either changestatus or changereminder, never both
+    ext.point('io.ox/calendar/links/inline').extend(new links.Link({
+        index: 155,
+        prio: 'hi',
+        mobile: 'hi',
+        id: 'changereminder',
+        label: gt('Change reminder'),
+        ref: 'io.ox/calendar/detail/actions/changeAlarms'
+    }));
+
     ext.point('io.ox/calendar/links/inline').extend(new links.Link({
         index: 200,
         prio: 'hi',
