@@ -93,8 +93,19 @@ define('io.ox/calendar/api', [
 
             return response;
         },
+        // checks if attendees have the extended Contact information (list request does not have them, get has them, we need to distinguish)
+        hasExtendedEntities = function (attendees) {
+            if (!attendees) return false;
+            var extendedEntities = true;
 
-        defaultFields = ['lastModified', 'color', 'createdBy', 'endDate', 'flags', 'folder', 'id', 'location', 'recurrenceId', 'seriesId', 'startDate', 'summary', 'timestamp', 'transp'].join(','),
+            _(attendees).each(function (attendee) {
+                // if we have an entity we need either contact or ressource information
+                if (attendee.entity && !(attendee.contact || attendee.resource)) extendedEntities = false;
+            });
+            return extendedEntities;
+        },
+
+        defaultFields = ['lastModified', 'color', 'createdBy', 'endDate', 'flags', 'folder', 'id', 'location', 'recurrenceId', 'rrule', 'seriesId', 'startDate', 'summary', 'timestamp', 'transp'].join(','),
 
         api = {
             // used externally by itip updates in mail invites
@@ -114,32 +125,43 @@ define('io.ox/calendar/api', [
                     });
                     return opt;
                 }
+                function merge(data1, data2) {
+                    return _(data1)
+                        .chain()
+                        .union(data2)
+                        .uniq(function (event) { return util.cid(event); })
+                        .compact()
+                        .value();
+                }
                 return function request(opt, method) {
                     method = method || 'GET';
                     return http[method](opt).then(function (result) {
                         if (_.isArray(result)) {
+                            var error;
                             result.forEach(function (r) {
                                 if (r.error) {
                                     ox.trigger('http:error:' + r.error.code, r.error);
+                                    error = r.error;
                                 }
                             });
+                            // only throw that specific error too many appointments error because otherwise this error might only affect a few folders
+                            if (error && error.code === 'CAL-5072') throw error;
                         }
                         return result;
-                    }, function (err) {
+                    }).catch(function (err) {
                         if (err.code !== 'CAL-5072') throw err;
 
-                        var start = moment(opt.params.rangeStart),
-                            end = moment(opt.params.rangeEnd),
+                        var start = moment(opt.params.rangeStart).utc(),
+                            end = moment(opt.params.rangeEnd).utc(),
                             middle = moment(start).add(end.diff(start, 'ms') / 2, 'ms');
 
                         return request(getParams(opt, start, middle), method).then(function (data1) {
                             return request(getParams(opt, middle, end), method).then(function (data2) {
-                                return _(data1)
-                                    .chain()
-                                    .union(data2)
-                                    .uniq(function (event) { return util.cid(event); })
-                                    .compact()
-                                    .value();
+                                if (!_.isArray(data1)) return merge(data1, data2);
+                                data1.forEach(function (d, index) {
+                                    d.events = merge(d.events, data2[index].events);
+                                });
+                                return data1;
                             });
                         });
                     });
@@ -152,7 +174,8 @@ define('io.ox/calendar/api', [
 
                 if (useCache !== false) {
                     var model = api.pool.getModel(util.cid(obj));
-                    if (model && (model.has('attendees') || model.has('calendarUser'))) return $.when(model);
+                    // check if we have a full model with extended entities
+                    if (model && hasExtendedEntities(model.get('attendees'))) return $.when(model);
                 }
                 // if an alarm object was used to get the associated event we need to use the eventId not the alarm Id
                 if (obj.eventId) {
@@ -206,8 +229,7 @@ define('io.ox/calendar/api', [
                     return http.PUT({
                         module: 'chronos',
                         params: {
-                            action: 'list',
-                            extendedEntities: true
+                            action: 'list'
                         },
                         data: list
                     }).catch(function (err) {
@@ -224,18 +246,22 @@ define('io.ox/calendar/api', [
                 }
                 return function (list, useCache) {
 
+                    var alarms = [];
                     list = _(list).map(function (obj) {
                         // if an alarm object was used to get the associated event we need to use the eventId not the alarm Id
                         if (obj.eventId) {
+                            alarms.push(obj);
                             return { id: obj.eventId, folder: obj.folder, recurrenceId: obj.recurrenceId };
                         }
                         return obj;
                     });
 
                     var def, reqList = list;
+
                     if (useCache !== false) {
                         reqList = list.filter(function (obj) {
-                            return !api.pool.getModel(util.cid(obj));
+                            var model = api.pool.getModel(util.cid(obj));
+                            return model && model.has('attendees');
                         });
                     }
 
@@ -244,20 +270,48 @@ define('io.ox/calendar/api', [
 
                     return def.then(function (data) {
                         if (data) {
-                            data.forEach(function (obj) {
+                            data.forEach(function (obj, index) {
+                                if (obj === null) {
+                                    var alarm = { eventId: reqList[index].id, folder: reqList[index].folder };
+                                    if (reqList[index].recurrenceId) alarm.recurrenceId = reqList[index].recurrenceId;
+                                    api.trigger('failedToFetchEvent', _(alarms).findWhere(alarm));
+                                    api.trigger('delete:appointment', reqList[index]);
+                                    // null means the event was deleted, clean up the caches
+                                    processResponse({
+                                        deleted: [reqList[index]]
+                                    });
+                                    return;
+                                }
                                 if (isRecurrenceMaster(obj)) return;
+
+                                var model = api.pool.getModel(util.cid(obj));
+                                // do not overwrite cache data that has extended entities and the same or newer lastModified timestamp
+                                if (model && hasExtendedEntities(model.get('attendees')) && (model.get('lastModified') >= obj.lastModified)) {
+                                    return;
+                                }
                                 api.pool.propagateAdd(obj);
                             });
                         }
 
-                        return list.map(function (obj, index) {
+                        return list.map(function (obj) {
                             // if we have full data use the full data, in list data recurrence ids might be missing
                             // you can request exceptions without recurrence id because they have own ids, but in the reponse they still have a recurrence id, which is needed for the correct cid
-                            if (data && data[index]) {
-                                obj = data[index];
+                            if (data) {
+                                // find correct index
+                                var index = _(reqList).findIndex(function (req) {
+                                    return req.id === obj.id && req.folder === obj.folder && (!req.recurrenceId || req.recurrenceId === obj.recurrenceId);
+                                });
+                                if (index !== -1 && data[index]) {
+                                    obj = data[index];
+                                } else if (index !== -1 && data[index] === null) {
+                                    // null is returned when the event was deleted meanwhile
+                                    return null;
+                                }
                             }
 
-                            if (isRecurrenceMaster(obj)) return api.pool.get('detail').add(data);
+                            if (isRecurrenceMaster(obj)) {
+                                return api.pool.get('detail').add(obj);
+                            }
                             var cid = util.cid(obj);
                             return api.pool.getModel(cid);
                         });
@@ -280,6 +334,8 @@ define('io.ox/calendar/api', [
                     },
                     def;
 
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                 if (options.expand) {
                     params.expand = true;
                     params.rangeStart = options.rangeStart;
@@ -332,7 +388,7 @@ define('io.ox/calendar/api', [
                         action: 'update',
                         folder: obj.folder,
                         id: obj.id,
-                        timestamp: obj.timestamp,
+                        timestamp: _.then(),
                         // convert to true boolean
                         checkConflicts: !!options.checkConflicts,
                         sendInternalNotifications: !!options.sendInternalNotifications,
@@ -340,6 +396,8 @@ define('io.ox/calendar/api', [
                         fields: api.defaultFields
                     };
 
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                 if (obj.recurrenceId) params.recurrenceId = obj.recurrenceId;
 
                 if (options.expand) {
@@ -348,10 +406,16 @@ define('io.ox/calendar/api', [
                     params.rangeEnd = options.rangeEnd;
                 }
 
+                var data = {
+                    event: obj
+                };
+
+                if (options.comment) data.comment = options.comment;
+
                 if (options.attachments && options.attachments.length) {
                     var formData = new FormData();
 
-                    formData.append('json_0', JSON.stringify(obj));
+                    formData.append('json_0', JSON.stringify(data));
                     for (var i = 0; i < options.attachments.length; i++) {
                         // the attachment data is given via the options parameter
                         formData.append('file_' + options.attachments[i].cid, options.attachments[i].file);
@@ -366,7 +430,7 @@ define('io.ox/calendar/api', [
                     def = http.PUT({
                         module: 'chronos',
                         params: params,
-                        data: obj
+                        data: data
                     });
                 }
                 return def.then(processResponse)
@@ -388,14 +452,29 @@ define('io.ox/calendar/api', [
             },
 
             remove: function (list, options) {
+                options = _.extend({}, options);
                 api.trigger('beforedelete', list);
                 list = _.isArray(list) ? list : [list];
 
                 var params = {
-                    action: 'delete',
-                    timestamp: _.now(),
-                    fields: api.defaultFields
-                };
+                        action: 'delete',
+                        timestamp: _.then(),
+                        fields: api.defaultFields
+                    },
+                    data = {
+                        events: _(list).map(function (obj) {
+                            obj = obj instanceof Backbone.Model ? obj.attributes : obj;
+                            var params = {
+                                id: obj.id,
+                                folder: obj.folder
+                            };
+                            if (obj.recurrenceId) params.recurrenceId = obj.recurrenceId;
+                            if (obj.recurrenceRange) params.recurrenceRange = obj.recurrenceRange;
+                            return params;
+                        })
+                    };
+
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
 
                 if (options.expand) {
                     params.expand = true;
@@ -403,19 +482,12 @@ define('io.ox/calendar/api', [
                     params.rangeEnd = options.rangeEnd;
                 }
 
+                if (options.comment) data.comment = options.comment;
+
                 return http.PUT({
                     module: 'chronos',
                     params: params,
-                    data: _(list).map(function (obj) {
-                        obj = obj instanceof Backbone.Model ? obj.attributes : obj;
-                        var params = {
-                            id: obj.id,
-                            folder: obj.folder
-                        };
-                        if (obj.recurrenceId) params.recurrenceId = obj.recurrenceId;
-                        if (obj.recurrenceRange) params.recurrenceRange = obj.recurrenceRange;
-                        return params;
-                    })
+                    data: data
                 })
                 .then(function (data) {
                     data.forEach(processResponse);
@@ -433,22 +505,29 @@ define('io.ox/calendar/api', [
                 // if comment schould be deleted, send null. Just like in settings
                 if (obj.attendee.comment === '') delete obj.attendee.comment;
 
+                // make sure alarms are explicitely set to null when declining, otherwise the user is reminded of declined appointments, we don't want that
+                // do this in api to catch all cases (shortcut buttons, full dialogs, mail invitations etc)
+                if (obj.attendee.partStat === 'DECLINED') obj.alarms = null;
+
                 var params = {
                         action: 'updateAttendee',
                         id: obj.id,
                         folder: obj.folder,
                         checkConflicts: options.checkConflicts,
-                        timestamp: _.now(),
+                        timestamp: _.then(),
                         fields: api.defaultFields
                     },
                     data = {
                         attendee: obj.attendee
                     };
 
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                 if (obj.recurrenceId) {
                     params.recurrenceId = obj.recurrenceId;
                 }
-                if (obj.alarms) {
+                // null means remove alarms
+                if (obj.alarms || obj.alarms === null) {
                     data.alarms = obj.alarms;
                 }
                 if (options.expand) {
@@ -479,6 +558,40 @@ define('io.ox/calendar/api', [
                 });
             },
 
+            updateAlarms: function (obj, options) {
+
+                var params = {
+                    action: 'updateAlarms',
+                    id: obj.id,
+                    folder: obj.folder,
+                    timestamp: _.now(),
+                    fields: api.defaultFields + ',alarms,rrule'
+                };
+
+                if (obj.recurrenceId) {
+                    params.recurrenceId = obj.recurrenceId;
+                }
+
+                if (options.expand) {
+                    params.expand = true;
+                    params.rangeStart = options.rangeStart;
+                    params.rangeEnd = options.rangeEnd;
+                }
+
+                return http.PUT({
+                    module: 'chronos/alarm',
+                    params: params,
+                    data: obj.alarms
+                })
+                .then(function (data) {
+                    // somehow the backend misses the alarms property when alarms are set to 0
+                    if (obj.alarms.length === 0 && !obj.recurrenceId) {
+                        data.updated[0].alarms = [];
+                    }
+                    processResponse(data);
+                });
+            },
+
             // returns freebusy data
             freebusy: function (list, options) {
                 if (list.length === 0) {
@@ -491,9 +604,10 @@ define('io.ox/calendar/api', [
                 }, options);
 
                 // entity for users ressources etc, uri for externals
-                var order = _(list).map(function (attendee) { return attendee.entity || attendee.uri; });
+                var order = _(list).map(function (attendee) { return attendee.entity || attendee.uri; }),
+                    def = $.Deferred();
 
-                return http.PUT({
+                http.PUT({
                     module: 'chronos',
                     params: {
                         action: 'freeBusy',
@@ -506,8 +620,34 @@ define('io.ox/calendar/api', [
                     items.sort(function (a, b) {
                         return order.indexOf(a.attendee.entity || a.attendee.uri) - order.indexOf(b.attendee.entity || b.attendee.uri);
                     });
-                    return items;
+                    def.resolve(items);
+                },
+                function (err) {
+                    // to many events
+                    if (err.code !== 'CAL-5072') def.reject(err);
+                    // split request and send as multiple instead
+                    http.pause();
+                    _(list).each(function (attendee) {
+                        http.PUT({
+                            module: 'chronos',
+                            params: {
+                                action: 'freeBusy',
+                                from: options.from,
+                                until: options.until
+                            },
+                            data: { attendees: [attendee] }
+                        });
+                    });
+                    http.resume().then(function (result) {
+                        // change errors to empty arrays. If theres an error with one attendee we can still show the rest
+                        result = result.map(function (singleResult) {
+                            return singleResult.error ? { freeBusyTime: [] } : singleResult.data[0];
+                        });
+                        def.resolve(result);
+                    });
                 });
+
+                return def;
             },
 
             reduce: function (obj) {
@@ -534,9 +674,12 @@ define('io.ox/calendar/api', [
                         folder: model.get('folder'),
                         targetFolder: targetFolderId,
                         recurrenceId: model.get('recurrenceId'),
-                        timestamp: model.get('timestamp'),
+                        timestamp: _.then(),
                         fields: api.defaultFields
                     };
+
+                    if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                     if (options.expand) {
                         params.expand = true;
                         params.rangeStart = options.rangeStart;
@@ -574,15 +717,16 @@ define('io.ox/calendar/api', [
             },
 
             getInvites: function () {
-                return api.request({
+                return http.GET({
                     module: 'chronos',
                     params: {
                         action: 'needsAction',
                         folder: folderApi.getDefaultFolder('calendar'),
                         rangeStart: moment().subtract(2, 'hours').utc().format(util.ZULU_FORMAT),
-                        rangeEnd: moment().add(1, 'years').utc().format(util.ZULU_FORMAT)
+                        rangeEnd: moment().add(1, 'years').utc().format(util.ZULU_FORMAT),
+                        fields: 'folder,id,recurrenceId,organizer,endDate,startDate,summary,location,rrule'
                     }
-                }, 'GET').then(function (data) {
+                }).then(function (data) {
                     // even if empty array is given it needs to be triggered to remove
                     // notifications that does not exist anymore (already handled in ox6 etc)
                     // no filtering needed because of new needsAction request
@@ -620,30 +764,42 @@ define('io.ox/calendar/api', [
                     });
                     return http.resume();
                 }
+                var params = {
+                    action: 'ack',
+                    folder: obj.folder,
+                    id: obj.eventId,
+                    alarmId: obj.alarmId
+                };
+
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                 return http.PUT({
                     module: 'chronos/alarm',
-                    params: {
-                        action: 'ack',
-                        folder: obj.folder,
-                        id: obj.eventId,
-                        alarmId: obj.alarmId
-                    }
+                    params: params
                 })
-                .then(processResponse);
+                .then(function (data) {
+                    api.trigger('acknowledgedAlarm', obj);
+                    processResponse(data);
+                    return data;
+                });
             },
 
             remindMeAgain: function (obj) {
                 if (!obj) return $.Deferred().reject();
 
+                var params = {
+                    action: 'snooze',
+                    folder: obj.folder,
+                    id: obj.eventId,
+                    alarmId: obj.alarmId,
+                    snoozeTime: obj.time || 300000
+                };
+
+                if (ox.socketConnectionId) params.pushToken = ox.socketConnectionId;
+
                 return http.PUT({
                     module: 'chronos/alarm',
-                    params: {
-                        action: 'snooze',
-                        folder: obj.folder,
-                        id: obj.eventId,
-                        alarmId: obj.alarmId,
-                        snoozeTime: obj.time || 300000
-                    }
+                    params: params
                 })
                 .then(processResponse);
             },
@@ -699,6 +855,18 @@ define('io.ox/calendar/api', [
         api.refresh();
     });
 
+    // sync caches if backend sends push update notice
+    // also get fresh alarms
+    ox.on('socket:calendar:updates', function (data) {
+        _(data.folders).each(function (folder) {
+            _(api.pool.getByFolder(folder)).each(function (collection) {
+                collection.expired = true;
+                collection.sync();
+            });
+        });
+        api.getAlarms();
+    });
+
     api.pool = Pool.create('chronos', {
         Collection: models.Collection
     });
