@@ -18,6 +18,7 @@ define('io.ox/calendar/edit/extensions', [
     'io.ox/contacts/util',
     'io.ox/mail/util',
     'io.ox/core/util',
+    'io.ox/core/tk/upload',
     'io.ox/backbone/views',
     'io.ox/backbone/mini-views',
     'io.ox/backbone/mini-views/datepicker',
@@ -35,12 +36,25 @@ define('io.ox/calendar/edit/extensions', [
     'io.ox/calendar/color-picker',
     'io.ox/backbone/mini-views/dropdown',
     'less!io.ox/calendar/style'
-], function (ext, gt, calendarUtil, contactUtil, mailUtil, coreUtil, views, mini, DatePicker, attachments, RecurrenceView, AlarmsView, api, AddParticipantView, pViews, capabilities, picker, folderAPI, settings, coreSettings, ColorPicker, Dropdown) {
+], function (ext, gt, calendarUtil, contactUtil, mailUtil, coreUtil, upload, views, mini, DatePicker, attachments, RecurrenceView, AlarmsView, api, AddParticipantView, pViews, capabilities, picker, folderAPI, settings, coreSettings, ColorPicker, Dropdown) {
 
     'use strict';
 
     var point = views.point('io.ox/calendar/edit/section');
 
+    point.basicExtend({
+        index: 100,
+        id: 'dnd',
+        draw: function (baton) {
+            baton.app.view.$el.append(
+                new upload.dnd.FloatingDropzone({
+                    app: baton.app,
+                    point: 'io.ox/calendar/edit/dnd/actions'
+                }).render().$el
+            );
+        }
+    });
+
     point.basicExtend({
         id: 'header',
         index: 10,
@@ -95,9 +109,7 @@ define('io.ox/calendar/edit/extensions', [
                     if (calendarUtil.isAllday(baton.model)) {
                         // save unchanged dates, so they can be restored on error or when handling conflicts
                         baton.parentView.tempEndDate = baton.model.get('endDate');
-                        baton.parentView.tempStartDate = baton.model.get('startDate');
                         baton.model.set('endDate', { value: moment(baton.model.get('endDate').value).add(1, 'days').format('YYYYMMDD') }, { silent: true });
-                        baton.model.set('startDate', { value: moment(baton.model.get('startDate').value).format('YYYYMMDD') }, { silent: true });
                     }
 
 
@@ -145,12 +157,13 @@ define('io.ox/calendar/edit/extensions', [
                     baton.app.attachmentsFormData = attachments;
                     if (baton.mode === 'edit') {
                         var options = _.extend(calendarUtil.getCurrentRangeOptions(), {
-                            recurrenceRange: baton.model.mode === 'thisandfuture' ? 'THISANDFUTURE' : undefined,
-                            attachments: attachments,
-                            checkConflicts: true,
-                            sendInternalNotifications: sendNotifications
-                        });
-                        api.update(baton.model, options).then(save, fail);
+                                recurrenceRange: baton.model.mode === 'thisandfuture' ? 'THISANDFUTURE' : undefined,
+                                attachments: attachments,
+                                checkConflicts: true,
+                                sendInternalNotifications: sendNotifications
+                            }),
+                            delta = baton.app.getDelta();
+                        api.update(delta, options).then(save, fail);
                         return;
                     }
 
@@ -195,69 +208,6 @@ define('io.ox/calendar/edit/extensions', [
         }
     });
 
-    var CalendarSelectionView = mini.AbstractView.extend({
-        tagName: 'div',
-        className: 'header-right',
-        events: {
-            'click a': 'onSelect'
-        },
-        setup: function () {
-            this.listenTo(this.model, 'change:folder', this.render);
-        },
-        onSelect: function () {
-            var self = this;
-
-            picker({
-                async: true,
-                button: gt('Select'),
-                flat: true,
-                indent: false,
-                module: 'calendar',
-                persistent: 'folderpopup',
-                root: '1',
-                settings: settings,
-                title: gt('Select calendar'),
-                createFolderText: gt('Create new calendar'),
-                folder: this.model.get('folder'),
-
-                done: function (id, dialog) {
-                    self.model.set('folder', id);
-                    dialog.close();
-                },
-
-                disable: function (data, options) {
-                    var create = folderAPI.can('create', data);
-                    return !create || (options && /^virtual/.test(options.folder));
-                }
-            });
-        },
-        render: function () {
-            var link = $('<a href="#">'),
-                folderId = this.model.get('folder');
-
-            folderAPI.get(folderId).done(function (folder) {
-                link.text(folder.display_title || folder.title);
-            });
-
-            this.$el.empty().append(
-                $('<span>').text(gt('Calendar:')),
-                link
-            );
-
-            return this;
-        }
-    });
-
-    ext.point('io.ox/calendar/edit/section/buttons').extend({
-        index: 1000,
-        id: 'folder-selection',
-        draw: function (baton) {
-            this.append(
-                new CalendarSelectionView({ model: baton.model }).render().$el
-            );
-        }
-    });
-
     // title
     point.extend({
         id: 'title',
@@ -309,7 +259,7 @@ define('io.ox/calendar/edit/extensions', [
         draw: function (baton) {
             baton.parentView.startDatePicker = new DatePicker({
                 model: baton.model,
-                className: 'col-xs-6',
+                className: 'col-sm-6 col-xs-12',
                 display: calendarUtil.isAllday(baton.model) ? 'DATE' : 'DATETIME',
                 attribute: 'startDate',
                 label: gt('Starts on'),
@@ -319,8 +269,6 @@ define('io.ox/calendar/edit/extensions', [
                     timeLabel: gt('Start time')
                 },
                 chronos: true
-            }).listenTo(baton.model, 'change:startDate', function (model) {
-                this.toggleTimeInput(!calendarUtil.isAllday(model));
             }).on('click:timezone', openTimezoneDialog, baton)
                 .on('click:time', function () {
                     var target = this.$el.find('.dropdown-menu.calendaredit'),
@@ -345,7 +293,7 @@ define('io.ox/calendar/edit/extensions', [
         draw: function (baton) {
             baton.parentView.endDatePicker = new DatePicker({
                 model: baton.model,
-                className: 'col-xs-6',
+                className: 'col-sm-6 col-xs-12',
                 display: calendarUtil.isAllday(baton.model) ? 'DATE' : 'DATETIME',
                 attribute: 'endDate',
                 label: gt('Ends on'),
@@ -355,8 +303,6 @@ define('io.ox/calendar/edit/extensions', [
                     timeLabel: gt('End time')
                 },
                 chronos: true
-            }).listenTo(baton.model, 'change:endDate', function (model) {
-                this.toggleTimeInput(!calendarUtil.isAllday(model));
             }).on('click:timezone', openTimezoneDialog, baton)
                 .on('click:time', function () {
                     var target = this.$el.find('.dropdown-menu.calendaredit'),
@@ -379,30 +325,27 @@ define('io.ox/calendar/edit/extensions', [
         index: 550,
         nextTo: 'end-date',
         render: function () {
-            var model = this.model,
+            var helpBlock = $('<div class="col-xs-12 help-block">').hide(),
                 userTimezone = moment().tz(),
-                helpBlock = $('<div class="col-xs-12 help-block">').hide();
+                self = this;
 
             function setHint() {
-                var startTimezone = model.getMoment('startDate').tz(),
-                    endTimezone = model.getMoment('endDate').tz(),
+                var startTimezone = self.baton.model.getMoment('startDate').tz(),
+                    endTimezone = self.baton.model.getMoment('endDate').tz(),
                     isVisible = startTimezone !== userTimezone || endTimezone !== userTimezone;
                 helpBlock.toggle(isVisible);
                 if (isVisible) {
-                    var start = model.getMoment('startDate'),
-                        end = model.getMoment('endDate'),
-                        interval = calendarUtil.getTimeInterval(model.attributes, moment().tz()),
-                        duration = moment.duration(end.diff(start, 'ms')).humanize();
-                    helpBlock.text(
-                        //#. %1$s timezone abbreviation of the user
-                        //#. %2$s time interval of event
-                        //#. %2$s duration of event
-                        gt('In your timezone (%1$s): %2$s (Duration: %3$s)', userTimezone, interval, duration)
+                    var interval = calendarUtil.getDateTimeIntervalMarkup(self.baton.model.attributes, { zone: moment().tz(), noTimezoneLabel: true });
+                    interval.prepend($('<span>').append(userTimezone + ': '));
+                    helpBlock.empty();
+                    helpBlock.append(
+                        interval
                     );
                 }
             }
+
             this.$el.append(helpBlock);
-            this.listenTo(model, 'change:startDate change:endDate', setHint);
+            this.listenTo(this.baton.model, 'change:startDate change:endDate', setHint);
             setHint();
         }
     });
@@ -443,7 +386,7 @@ define('io.ox/calendar/edit/extensions', [
         index: 650,
         nextTo: 'full_time',
         draw: function (baton) {
-            if (capabilities.has('freebusy !alone') && _.device('desktop')) {
+            if (capabilities.has('freebusy !alone !guest') && _.device('desktop')) {
                 this.append(
                     $('<div class="hidden-xs col-sm-6 find-free-time">').append(
                         $('<button type="button" class="btn btn-link">').text(gt('Find a free time'))
@@ -460,9 +403,33 @@ define('io.ox/calendar/edit/extensions', [
         className: 'col-xs-12',
         index: 650,
         render: function () {
-            this.$el.append(new RecurrenceView({
-                model: this.model
-            }).render().$el);
+            var helpNode = $('<div class="alert">'),
+                errorText = gt('Your recurrence rule does not fit to your start date.'),
+                helpText = gt('Your recurrence rule was changed automatically.'),
+                self = this,
+                recurrenceView = new RecurrenceView({
+                    model: this.model
+                });
+            this.$el.append(
+                recurrenceView.render().$el,
+                helpNode.hide()
+            );
+
+            this.model.on('change:rrule', function () {
+                if (!self.model.get('rrule')) {
+                    helpNode.hide();
+                    return;
+                }
+                // just return, no hide here (autochange hint might be there)
+                if (self.model.checkRecurrenceRule()) return;
+                helpNode.removeClass('alert-info').addClass('alert-warning').text(errorText).show();
+            });
+            this.model.getRruleMapModel().on('autochanged', function () {
+                helpNode.removeClass('alert-warning').addClass('alert-info').text(helpText).show();
+            });
+            recurrenceView.on('openeddialog', function () {
+                helpNode.hide();
+            });
         }
     });
 
@@ -480,6 +447,133 @@ define('io.ox/calendar/edit/extensions', [
         }
     });
 
+    var CalendarDropdownView = mini.AbstractView.extend({
+
+        tagName: 'fieldset',
+        dropDown: {},
+        $toggle: $('<button class="btn btn-link dropdown-toggle" data-toggle="dropdown" type="button" aria-haspopup="true">'),
+
+        getColor: function (folder) {
+            var props = folder['com.openexchange.calendar.extendedProperties'],
+                color = settings.get('defaultFolderColor', '#CFE6FF');
+
+            if (props && props.color && props.color.value) color = props.color.value;
+            var label = _(calendarUtil.colors).findWhere({ value: color }) || {};
+            return { value: color, label: label.label || gt('User defined color') };
+        },
+
+        setup: function () {
+            var self = this;
+
+            this.listenTo(this.model, 'change:folder', function (model, folder) {
+                var getNewModel = folderAPI.get(folder),
+                    getPreviousModel = folderAPI.get(self.model.previous('folder'));
+
+                $.when(getNewModel, getPreviousModel).done(function (newModel, previousModel) {
+                    var prevOrg = self.model.previousAttributes().organizer.entity;
+                    // check if we need to make changes to the appointment
+                    // needed when switch from shared to private or private to shared happens
+                    if (folderAPI.is('shared', newModel) || folderAPI.is('shared', previousModel)) {
+                        self.model.setDefaultAttendees({ create: true, resetStates: !self.model.get('id') }).done(function () {
+                            // trigger reset to trigger a redrawing of all participants (avoid 2 organizers)
+                            self.model.getAttendees().trigger('reset');
+                            // same organizer? No message needed (switched between shared calendars of the same user)
+                            if (prevOrg === self.model.get('organizer').entity) return;
+
+                            require(['io.ox/core/yell'], function (yell) {
+                                if (folderAPI.is('shared', newModel)) {
+                                    yell('info', gt('You are using a shared calendar. The calendar owner was added as organizer.'));
+                                } else {
+                                    yell('info', gt('You are no longer using a shared calendar. You were added as organizer.'));
+                                }
+                            });
+                        });
+                    }
+                });
+
+                self.update();
+            });
+        },
+
+        update: function () {
+            var self = this;
+
+            folderAPI.get(self.model.get('folder')).done(function (folder) {
+                var folderLabel = folder.display_title || folder.title;
+                self.$toggle.text(folderLabel);
+            });
+
+            self.dropDown.update();
+        },
+
+        render: function () {
+            var self = this,
+                folderDef = folderAPI.get(self.model.get('folder')),
+                folderSectionsDef = folderAPI.flat({ module: 'calendar' });
+
+            self.dropDown = new Dropdown({ caret: false, model: self.model, $toggle: self.$toggle });
+
+            $.when(folderDef, folderSectionsDef).done(function (folder, folderSections) {
+
+                //var color = self.getColor(folder),
+                var folderLabel = folder.display_title || folder.title,
+                    folderNames = {
+                        'private':  gt('My calendars'),
+                        'public':   gt('Public calendars'),
+                        'shared':   gt('Shared calendars'),
+                        'hidden':   gt('Hidden calendars')
+                    },
+                    i = 0;
+
+                function addSection(text, sectionName) {
+                    var folderSection = folderSections[sectionName];
+                    if (!folderSection || folderSection.length === 0) return;
+
+                    folderSection = _(folderSection).filter(function (folder) {
+                        var create = folderAPI.can('create', folder),
+                            // we dont allow moving an already existing appointment to a folder from another user (moving from shared user A's folder to shared user A's folder is allowed).
+                            allowed = !self.model.get('id') || folderAPI.is('public', folder) || folder.created_by === self.model.get('organizer').entity;
+
+                        return (create && allowed && !/^virtual/.test(folder.id));
+                    });
+
+                    if (folderSection.length === 0) return;
+
+                    if (i !== 0) self.dropDown.divider();
+                    self.dropDown.header(text);
+
+                    _(folderSection).forEach(function (folder) {
+                        var checkboxColor = self.getColor(folder);
+                        self.dropDown.option(
+                            'folder',
+                            folder.id,
+                            function () {
+                                return [
+                                    $.txt(folder.display_title || folder.title),
+                                    $('<span class="sr-only">').text(', ' + gt('Color') + ': ' + checkboxColor.label)
+                                ];
+                            },
+                            { radio: true, color: checkboxColor.value }
+                        );
+                    });
+                    i++;
+                }
+
+                self.$toggle.text(folderLabel);
+
+                _(folderNames).each(addSection);
+
+                self.$el.append(
+                    $('<legend>').addClass('simple').text(gt('Calendar')),
+                    self.dropDown.render().$el
+                );
+            });
+
+            return this;
+        }
+    });
+
+
     // separator or toggle
     point.basicExtend({
         id: 'noteSeparator',
@@ -508,7 +602,7 @@ define('io.ox/calendar/edit/extensions', [
     point.basicExtend({
         id: 'participants_list',
         index: 800,
-        rowClass: 'collapsed form-spacer',
+        rowClass: 'collapsed',
         draw: function (baton) {
             this.append(new pViews.UserContainer({
                 collection: baton.model.getAttendees(),
@@ -544,6 +638,18 @@ define('io.ox/calendar/edit/extensions', [
         }
     });
 
+    point.extend({
+        id: 'folder-selection',
+        index: 950,
+        className: 'col-xs-12 folder-selection',
+        render: function () {
+            var view = new CalendarDropdownView({ model: this.model }).render().$el;
+            this.$el.append(view).addClass('col-xs-12');
+        }
+    }, {
+        rowClass: 'collapsed form-spacer'
+    });
+
     // alarms
     point.extend({
         id: 'alarms',
@@ -558,8 +664,6 @@ define('io.ox/calendar/edit/extensions', [
                 )
             );
         }
-    }, {
-        rowClass: 'collapsed form-spacer'
     });
 
     // private checkbox
@@ -572,9 +676,9 @@ define('io.ox/calendar/edit/extensions', [
             // visibility flag only works in private folders
             var folder = this.model.get('folder');
             if (!folderAPI.pool.getModel(folder).is('private')) return;
-
-            var helpNode = $('<a href="#" tabindex="0" role="button" class="visibility-helper-button btn btn-link" data-toggle="popover" data-trigger="focus hover" data-placement="left" data-content=" ">').append('<i class="fa fa-question-circle">')
-                .attr('data-template', '<div class="popover calendar-popover" role="tooltip"><div class="arrow"></div><div>' +
+            var popoverUid = _.uniqueId('popover-'),
+                helpNode = $('<button type="button" class="visibility-helper-button btn btn-link" data-toggle="popover" data-trigger="manual" data-placement="left" data-content=" ">').attr('aria-label', gt('Visibility Help')).append('<i class="fa fa-question-circle" aria-hidden="true">')
+                .attr('data-template', '<div class="popover calendar-popover" role="tooltip"><div class="arrow"></div><div id="' + popoverUid + '">' +
                     '<div class="ox-popover-title">' + gt('Standard') + '</div>' +
                     '<div>' + gt('The appointment is visible for all users in shared calendars.') + '</div>' +
                     '<div class="ox-popover-title">' + gt('Private') + '</div>' +
@@ -584,12 +688,20 @@ define('io.ox/calendar/edit/extensions', [
                     '</div></div>')
                     .popover({
                         container: '#' + this.baton.app.get('window').id + ' .window-content.scrollable'
+                    })
+                    .on('blur', function () { helpNode.popover('hide'); })
+                    .on('click', function () { helpNode.popover('toggle'); })
+                    .on('keydown', function (e) {
+                        if (e.which !== 27) return;
+                        if ($('#' + popoverUid).is(':visible')) e.stopImmediatePropagation();
+                        helpNode.popover('hide');
                     }),
                 guid = _.uniqueId('form-control-label-');
 
             this.$el.append(
                 $('<div>').append(
-                    $('<label class="simple">').attr('for', guid).text(gt('Visibility')).append(helpNode),
+                    $('<label class="simple">').attr('for', guid).text(gt('Visibility')),
+                    helpNode,
                     new mini.SelectView({ id: guid, label: gt('Visibility'), name: 'class', model: this.model, list: [
                         { value: 'PUBLIC', label: gt('Standard') },
                         { value: 'CONFIDENTIAL', label: gt('Private') },
@@ -620,36 +732,46 @@ define('io.ox/calendar/edit/extensions', [
                 }),
                 toggle = $('<button class="btn btn-link dropdown-toggle" data-toggle="dropdown" type="button" aria-haspopup="true">').text(gt('Appointment color')),
                 menu = $('<ul class="dropdown-menu">'),
+                pickedColor = $('<span class="picked-color" aria-hidden="true">'),
+                pickedColorLabel = $('<span class="sr-only">'),
                 dropdown = new Dropdown({
-                    smart: false,
-                    className: 'color-picker-dropdown dropup',
-                    $toggle: toggle,
+                    smart: true,
+                    className: 'color-picker-dropdown dropdown',
+                    $toggle: toggle.append(pickedColor, pickedColorLabel),
                     $ul: menu,
                     margin: 24,
                     model: this.model,
                     carret: true,
                     allowUndefined: true
-                }),
-                pickedColor = $('<span class="picked-color">');
-            dropdown.option('color', undefined, gt('No color'));
-            dropdown.divider();
-            menu.append($('<li role="presentation">').append(picker.render().$el));
+                });
+            //#. showed inside a color picker. Used if an appointment should not have a custom color
+            dropdown.option('color', '', gt('Use calendar color'), { radio: true });
+            dropdown.$ul.find('[data-name="color"]').addClass('folder-default-color');
+            menu.append($('<li role="presentation" class="io-ox-calendar-color-picker-container">').append($('<div class="color-picker-scroll">').append(picker.render().$el)));
 
-            this.$el.append(
-                pickedColor,
-                dropdown.render().$el
-            );
+            this.$el.append(dropdown.render().$el);
 
             function onChangeColor() {
+                var colorLabel = gt('none');
                 if (!self.model.get('color')) {
-                    pickedColor.addClass('no-color').css('background-color', '#fff');
+                    // try to get the folder color
+                    var model = folderAPI.pool.getModel(self.model.get('folder')) || new Backbone.Model(),
+                        props = model.get('com.openexchange.calendar.extendedProperties') || {},
+                        color = '#fff';
+
+                    if (props.color && props.color.value) color = props.color.value;
+                    pickedColor.css({ 'background-color': color });
+                    if (_(calendarUtil.colors).findWhere({ value: color })) colorLabel = _(calendarUtil.colors).findWhere({ value: color }).label;
+                    pickedColorLabel.text(colorLabel);
                     picker.$el.find(':checked').prop('checked', false);
                     return;
                 }
-                pickedColor.removeClass('no-color').css('background-color', self.model.get('color'));
+                if (_(calendarUtil.colors).findWhere({ value: self.model.get('color') })) colorLabel = _(calendarUtil.colors).findWhere({ value: self.model.get('color') }).label;
+                pickedColorLabel.text(colorLabel);
+                pickedColor.css('background-color', self.model.get('color'));
             }
 
-            this.model.on('change:color', onChangeColor);
+            this.model.on('change:color change:folder', onChangeColor);
             onChangeColor();
         }
     }, {
