@@ -11,27 +11,30 @@
  * @author Daniel Dickhaus <daniel.dickhaus@open-xchange.com>
  */
 
-define('io.ox/calendar/freetime/model', ['settings!io.ox/calendar', 'io.ox/participants/model'], function (settings, participantsModel) {
+define('io.ox/calendar/freetime/model', [
+    'settings!io.ox/calendar',
+    'io.ox/calendar/model'
+], function (settings, models) {
 
     'use strict';
 
     var model = Backbone.Model.extend({
         initialize: function () {
-            var now = moment().startOf('week');
+            var now = moment().startOf(settings.get('scheduling/dateRange', 'week'));
             this.set({
                 timezone: now.tz(),
-                currentWeek: now,
+                startDate: now,
                 compact: settings.get('scheduling/compact', false),
                 zoom: settings.get('scheduling/zoom', '100'),
                 onlyWorkingHours: settings.get('scheduling/onlyWorkingHours', true),
                 startHour: Math.max(parseInt(settings.get('startTime', 8), 10) - 1, 0),
                 endHour: Math.min(parseInt(settings.get('endTime', 18), 10), 24),
-                participants: new participantsModel.Participants([], { splitGroups: true }),
+                attendees: new models.AttendeeCollection(null, { resolveGroups: true }),
                 showFree: settings.get('scheduling/showFree', false),
-                showAbsent: settings.get('scheduling/showAbsent', true),
                 showReserved: settings.get('scheduling/showReserved', true),
-                showTemporary: settings.get('scheduling/showTemporary', true),
-                appointments: {}
+                showFineGrid: settings.get('scheduling/showFineGrid', false),
+                timeSlots: {},
+                dateRange: settings.get('scheduling/dateRange', 'week')
             });
         }
     });
