@@ -45,6 +45,7 @@ define('io.ox/calendar/main', [
         }), win;
 
     app.mediator({
+
         /*
          * Init pages for mobile use
          * Each View will get a single page with own
@@ -67,6 +68,13 @@ define('io.ox/calendar/main', [
 
             win.nodes.body.addClass('classic-toolbar-visible').append(navbar, toolbar);
 
+            // create empty startup page
+            // such that the first change:page will always trigger a real page change with view initialization
+            app.pages.addPage({
+                name: 'start',
+                startPage: true
+            });
+
             app.pages.addPage({
                 name: 'folderTree',
                 navbar: new Bars.NavbarView({
@@ -86,12 +94,11 @@ define('io.ox/calendar/main', [
                     baton: baton,
                     page: 'month',
                     extension: 'io.ox/calendar/mobile/toolbar'
-                }),
-                startPage: true
+                })
             });
 
             app.pages.addPage({
-                name: 'week',
+                name: 'week:day',
                 navbar: new Bars.NavbarView({
                     baton: baton,
                     extension: 'io.ox/calendar/mobile/navbar'
@@ -139,7 +146,7 @@ define('io.ox/calendar/main', [
             // tell page controller about special navigation rules
             app.pages.setBackbuttonRules({
                 'month': 'folderTree',
-                'week': 'month',
+                'week:day': 'month',
                 'list': 'folderTree'
             });
         },
@@ -152,15 +159,31 @@ define('io.ox/calendar/main', [
 
             app.pages = new PageController({ appname: app.options.name });
 
-            // create 3 pages with toolbars and navbars
+            // create empty startup page
+            // such that the first change:page will always trigger a real page change with view initialization
             app.pages.addPage({
-                name: 'month',
+                name: 'start',
                 container: c,
                 startPage: true
             });
 
             app.pages.addPage({
-                name: 'week',
+                name: 'month',
+                container: c
+            });
+
+            app.pages.addPage({
+                name: 'week:day',
+                container: c
+            });
+
+            app.pages.addPage({
+                name: 'week:workweek',
+                container: c
+            });
+
+            app.pages.addPage({
+                name: 'week:week',
                 container: c
             });
 
@@ -217,9 +240,9 @@ define('io.ox/calendar/main', [
                 })
                 .setLeft(gt('Folders'));
 
-            app.pages.getNavbar('week')
+            app.pages.getNavbar('week:day')
                 .on('leftAction', function () {
-                    ox.ui.Perspective.show(app, 'month', { animation: 'slideright' });
+                    app.pages.changePage('month', { animation: 'slideright' });
                 })
                 .setLeft(gt('Back'));
 
@@ -329,15 +352,8 @@ define('io.ox/calendar/main', [
                 indent: false,
                 module: 'calendar'
             });
-
-            var cb = function () {
-                if (app.getWindow().currentPerspective !== 'month') {
-                    ox.ui.Perspective.show(app, 'month');
-                }
-            };
-
             // initialize folder view
-            FolderView.initialize({ app: app, tree: tree, firstResponder: 'month', respondCallback: cb });
+            FolderView.initialize({ app: app, tree: tree, firstResponder: 'month' });
             page.append(tree.render().$el);
             app.treeView = tree;
         },
@@ -356,6 +372,7 @@ define('io.ox/calendar/main', [
             });
             api.on('all:fail', function (id) {
                 app.folders.remove(id, { silent: true });
+                folderAPI.refresh();
             });
         },
 
@@ -433,6 +450,40 @@ define('io.ox/calendar/main', [
             });
         },
 
+        'views': function (app) {
+            var list = ['week:day', 'month', 'list'],
+                defaultPage = _.device('smartphone') ? 'week:day' : 'week:workweek',
+                views = {};
+            if (_.device('!smartphone')) list.push('week:workweek', 'week:week', 'year');
+            list.forEach(function (item) {
+                var node = app.pages.getPage(item);
+                node.one('pagebeforeshow', function () {
+                    var split = item.split(':'),
+                        view = split[0] || 'week',
+                        mode = split[1] || (_.device('smartphone') ? 'day' : 'workweek');
+
+                    require(['io.ox/calendar/' + view + '/view']).then(function success(View) {
+                        var view = new View({ mode: mode, app: app });
+                        node.append(view.$el);
+                        view.render();
+                        app.getWindow().trigger('change:perspective', view);
+                        app.perspective = views[item] = view;
+                        // finally store the layout. will not change anything if already selected
+                        app.props.set('layout', item);
+                    }, function fail() {
+                        if (item !== defaultPage) return app.pages.changePage(defaultPage);
+                    });
+                });
+                node.on('pagebeforeshow', function () {
+                    _.url.hash('perspective', item);
+                    if (!views[item]) return;
+                    views[item].trigger('show');
+                    app.perspective = views[item];
+                    if (_.device('smartphone')) settings.set('viewView', item);
+                });
+            });
+        },
+
         'listview': function (app) {
             app.listView = new CalendarListView({ app: app, draggable: false, pagination: false, labels: true, ignoreFocus: true, noPullToRefresh: true });
             app.listView.model.set({ view: 'list' }, { silent: true });
@@ -491,7 +542,8 @@ define('io.ox/calendar/main', [
          */
         'props': function (app) {
 
-            var view = settings.get('viewView') || 'week:week';
+            var view = _.device('!smartphone') ? settings.get('viewView') : undefined;
+            if (!view) view = 'week:week';
 
             // introduce shared properties
             app.props = new Backbone.Model({
@@ -553,7 +605,7 @@ define('io.ox/calendar/main', [
                 if (!options || options.fluent || app.props.get('find-result')) return;
                 var data = app.props.toJSON();
                 app.settings
-                    .set('viewView', data.layout)
+                    .set('viewView', _.device('smartphone') ? app.settings.get('viewView') : data.layout)
                     .set('showCheckboxes', data.checkboxes)
                     .set('showMiniCalendar', data.showMiniCalendar)
                     .set('showMonthviewWeekend', data.showMonthviewWeekend)
@@ -600,7 +652,7 @@ define('io.ox/calendar/main', [
         'change:layout': function (app) {
             app.props.on('change:layout', function (model, value) {
                 // no animations on desktop
-                ox.ui.Perspective.show(app, value, { disableAnimations: true });
+                app.pages.changePage(value, { disableAnimations: true });
             });
         },
 
@@ -689,24 +741,14 @@ define('io.ox/calendar/main', [
             return app.get('find') ? registerHandler(app, app.get('find')) : app.once('change:find', registerHandler);
         },
 
-        /*
-         * mobile only
-         * change current date label in navbar
-         */
-        'change:navbar:date-mobile': function (app) {
-            if (_.device('!smartphone')) return;
-            app.pages.getPage('week').on('change:navbar:date', function (e, dates) {
-                app.pages.getNavbar('week').setTitle(dates.date);
-            });
-        },
         /*
          * mobile only
          *
          */
         'show-weekview-mobile': function (app) {
             if (_.device('!smartphone')) return;
-            app.pages.getPage('week').on('pageshow', function () {
-                app.pages.getNavbar('week').setLeft(app.getDate().format('MMMM'));
+            app.pages.getPage('week:day').on('pageshow', function () {
+                app.pages.getNavbar('week:day').setLeft(app.getDate().format('MMMM'));
                 //app.pages.getPageObject('week').perspective.view.setScrollPos();
             });
         },
@@ -728,6 +770,7 @@ define('io.ox/calendar/main', [
          * Add support for virtual folder "All my public appointments"
          */
         'virtual-folders': function (app) {
+            if (capabilities.has('guest')) return;
             app.folderView.tree.selection.addSelectableVirtualFolder('cal://0/allPublic');
         },
 
@@ -883,6 +926,21 @@ define('io.ox/calendar/main', [
 
     });
 
+    function getPerspective(perspective) {
+        // check at first, if this is a known perspective
+        if (['week:day', 'month', 'list', 'week:workweek', 'week:week', 'year'].indexOf(perspective) < 0) {
+            perspective = _.device('smartphone') ? 'week:day' : 'week:workweek';
+        }
+
+        if (_.device('smartphone') && _.indexOf(['week:workweek', 'week:week', 'calendar'], perspective) >= 0) {
+            perspective = 'week:day';
+        } else if (_.device('smartphone') && _.indexOf(['week:day', 'list', 'month'], perspective) < 0) {
+            perspective = 'week:day';
+        }
+
+        return perspective;
+    }
+
     // launcher
     app.setLauncher(function (options) {
 
@@ -919,22 +977,17 @@ define('io.ox/calendar/main', [
                     app.mediate();
                     win.show();
                 })
+                .fail(function (result) {
+                    var message = gt('Application may not work as expected until this problem is solved.');
+                    if (result && result.error) message = result.error + ' ' + message;
+                    require(['io.ox/core/notifications'], function (notifications) {
+                        notifications.yell('error', message);
+                    });
+                })
                 .done(function () {
                     // app perspective
-                    var lastPerspective = options.perspective || _.sanitize.option(_.url.hash('perspective')) || app.props.get('layout');
-
-                    if (_.device('smartphone') && _.indexOf(['week:workweek', 'week:week', 'calendar'], lastPerspective) >= 0) {
-                        lastPerspective = 'week:day';
-                    } else if (lastPerspective === 'calendar') {
-                        // corrupt data fix
-                        lastPerspective = 'week:workweek';
-                    }
-
-                    ox.ui.Perspective.show(app, lastPerspective, { disableAnimations: true })
-                        .then(undefined, function applyFallback() {
-                            lastPerspective = 'week:workweek';
-                            return ox.ui.Perspective.show(app, lastPerspective, { disableAnimations: true });
-                        }).done(function () { app.props.set('layout', lastPerspective); });
+                    var lastPerspective = getPerspective(options.perspective || _.sanitize.option(_.url.hash('perspective')) || app.props.get('layout'));
+                    app.pages.changePage(lastPerspective, { disableAnimations: true });
                 });
         }
     });
@@ -952,14 +1005,8 @@ define('io.ox/calendar/main', [
                 defs.push(this.folder.set(options.folder));
             }
             if (options.perspective && options.perspective !== app.props.get('layout')) {
-                var perspective = options.perspective;
-                if (_.device('smartphone') && _.indexOf(['week:workweek', 'week:week', 'calendar'], perspective) >= 0) {
-                    perspective = 'week:day';
-                } else if (perspective === 'calendar') {
-                    // corrupt data fix
-                    perspective = 'week:workweek';
-                }
-                defs.push(app.props.set('layout', perspective));
+                var perspective = getPerspective(options.perspective);
+                if (_.device('smartphone')) defs.push(app.props.set('layout', perspective));
             }
             ret = $.when.apply(this, defs);
             ret.always(function () {
