@@ -51,7 +51,6 @@ define('io.ox/calendar/toolbar', [
             mobile: 'hi',
             label: gt.pgettext('app', 'Scheduling'),
             title: gt('Find a free time'),
-            drawDisabled: true,
             ref: 'io.ox/calendar/actions/freebusy'
         },
         'today': {
@@ -144,14 +143,14 @@ define('io.ox/calendar/toolbar', [
     }
 
     function updatePrintLink(baton) {
-        if (baton.app.getWindow().currentPerspective !== 'list') return;
+        if (baton.app.perspective.getName() !== 'list') return;
         var link = this.$el.find('[data-name="print"]');
         link.toggleClass('disabled', baton.data && _.isEmpty(baton.data));
     }
 
     function print(baton, e) {
         e.preventDefault();
-        if (baton.app.getWindow().currentPerspective === 'list') {
+        if (baton.app.perspective.getName() === 'list') {
             if (!baton.data || _.isEmpty(baton.data)) return;
             actions.invoke('io.ox/calendar/detail/actions/print-appointment', null, baton);
         } else {
@@ -165,26 +164,26 @@ define('io.ox/calendar/toolbar', [
         index: 10000,
         draw: function (baton) {
             //#. View is used as a noun in the toolbar. Clicking the button opens a popup with options related to the View
-            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li' })
-            .header(gt('Layout'))
-            .option('layout', 'week:day', gt('Day'), { radio: true });
-            if (_.device('!smartphone')) dropdown.option('layout', 'week:workweek', gt('Workweek'), { radio: true });
-            dropdown.option('layout', 'week:week', gt('Week'), { radio: true })
-                .option('layout', 'month', gt('Month'), { radio: true })
-                .option('layout', 'year', gt('Year'), { radio: true })
-                .option('layout', 'list', gt('List'), { radio: true })
+            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li', attributes: { role: 'presentation' } })
+            .group(gt('Layout'))
+            .option('layout', 'week:day', gt('Day'), { radio: true, group: true });
+            if (_.device('!smartphone')) dropdown.option('layout', 'week:workweek', gt('Workweek'), { radio: true, group: true });
+            dropdown.option('layout', 'week:week', gt('Week'), { radio: true, group: true })
+                .option('layout', 'month', gt('Month'), { radio: true, group: true })
+                .option('layout', 'year', gt('Year'), { radio: true, group: true })
+                .option('layout', 'list', gt('List'), { radio: true, group: true })
                 .divider()
-                .header(gt('Options'))
-                .option('folderview', true, gt('Folder view'))
-                .option('showMiniCalendar', true, gt('Mini calendar'));
+                .group(gt('Options'))
+                .option('folderview', true, gt('Folder view'), { group: true })
+                .option('showMiniCalendar', true, gt('Mini calendar'), { group: true });
 
             if (baton.app.props.get('layout') === 'month') {
-                dropdown.option('showMonthviewWeekend', true, gt('Weekends'));
+                dropdown.option('showMonthviewWeekend', true, gt('Weekends'), { group: true });
                 // dropdown.option('showMonthviewCW', true, gt('CW'));
             }
 
             dropdown
-                .option('checkboxes', true, gt('Checkboxes'))
+                .option('checkboxes', true, gt('Checkboxes'), { group: true })
                 .listenTo(baton.app.props, 'change:layout', updateCheckboxOption)
                 .listenTo(baton.app.props, 'change:layout', updateColorOption);
 
@@ -245,8 +244,8 @@ define('io.ox/calendar/toolbar', [
     });
 
     function prepareUpdateToolbar(app) {
-        var perspective = app.getWindow().getPerspective(),
-            list = perspective && perspective.name === 'list' ? app.listView.selection.get() : {};
+        var perspective = app.perspective,
+            list = perspective && perspective.getName() === 'list' ? app.listView.selection.get() : {};
         list = _(list).map(function (item) {
             if (_.isString(item)) return util.cid(item);
             return item;
