@@ -165,10 +165,10 @@ define('io.ox/contacts/toolbar', [
         draw: function (baton) {
 
             //#. View is used as a noun in the toolbar. Clicking the button opens a popup with options related to the View
-            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li' })
-            .header(gt('Options'))
-            .option('folderview', true, gt('Folder view'))
-            .option('checkboxes', true, gt('Checkboxes'));
+            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li', attributes: { role: 'presentation' } })
+                .group(gt('Options'))
+                .option('folderview', true, gt('Folder view'), { group: true })
+                .option('checkboxes', true, gt('Checkboxes'), { group: true });
 
             this.append(
                 dropdown.render().$el.addClass('pull-right').attr('data-dropdown', 'view')
