@@ -23,6 +23,7 @@ define('io.ox/contacts/view-detail', [
     'io.ox/core/folder/breadcrumb',
     'io.ox/core/extPatterns/links',
     'io.ox/core/util',
+    'io.ox/core/locale/postal-address',
     'io.ox/core/capabilities',
     'gettext!io.ox/contacts',
     'settings!io.ox/contacts',
@@ -30,7 +31,7 @@ define('io.ox/contacts/view-detail', [
     'io.ox/core/http',
     'static/3rd.party/purify.min.js',
     'less!io.ox/contacts/style'
-], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt, settings, attachments, http, DOMPurify) {
+], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, postalAddress, capabilities, gt, settings, attachments, http, DOMPurify) {
 
     'use strict';
 
@@ -408,21 +409,9 @@ define('io.ox/contacts/view-detail', [
     // type is 'business' or 'home' or 'other'
     function address(data, type) {
 
-        data = _(['street', 'postal_code', 'city', 'state', 'country']).map(function (field) {
-            return data[field + '_' + type] || '';
-        });
-
-        if (!_.some(data)) return null;
-
-        var text =
-            //#. Format of addresses
-            //#. %1$s is the street
-            //#. %2$s is the postal code
-            //#. %3$s is the city
-            //#. %4$s is the state
-            //#. %5$s is the country
-            gt('%1$s\n%2$s %3$s\n%4$s\n%5$s', data[0], data[1], data[2], data[3], data[4]);
+        var text = postalAddress.format(data, type);
 
+        if (!text) return null;
         var services = {
             google: { label: gt('Google Maps'), url: 'https://www.google.com/maps?q=' },
             osm: { label: gt('Open Street Map'), url: 'https://www.openstreetmap.org/search?query=' },
@@ -731,6 +720,8 @@ define('io.ox/contacts/view-detail', [
                 return '<a href="callto:' + number + '">' + match + '</a>';
             });
 
+            str = coreUtil.urlify(str);
+
             // fix missing newlines
             str = str.replace(/\n/g, '<br>');
 
