@@ -423,7 +423,6 @@ define('io.ox/core/api/account', [
      * @return { promise} returns array of arrays
      */
     api.getAllSenderAddresses = function () {
-
         return api.all()
         .then(function (list) {
             // only consider external accounts with a transport_url (see bug 48344)
@@ -464,13 +463,15 @@ define('io.ox/core/api/account', [
      * get all accounts
      * @return { deferred} returns array of account object
      */
-    api.all = function () {
+    api.all = function (options) {
+        var opt = _.extend({ useCache: true }, options);
+
         function load() {
-            if (_(api.cache).size() > 0) {
+            if (_(api.cache).size() > 0 && opt.useCache) {
                 // cache hit
                 return $.Deferred().resolve(_(api.cache).values());
             }
-            // cache miss
+            // cache miss, refill cache on success
             return http.GET({
                 module: 'account',
                 params: { action: 'all' },
@@ -762,8 +763,7 @@ define('io.ox/core/api/account', [
      */
 
     api.reload = function () {
-        api.cache = {};
-        return api.all();
+        return api.all({ useCache: false });
     };
 
     api.refresh = function () {
