@@ -166,7 +166,7 @@ define('io.ox/core/api/factory', [
                         return data;
                     }, function (error) {
                         api.trigger('error error:' + error.code, error);
-                        return error;
+                        throw error;
                     })
                     .then(function (data) {
                         return (o.pipe.all || _.identity)(data, opt);
@@ -287,7 +287,7 @@ define('io.ox/core/api/factory', [
                         return (o.pipe.get || _.identity)(data, opt);
                     }, function (error) {
                         api.trigger('error error:' + error.code, error);
-                        return error;
+                        throw error;
                     })
                     .then(function (data) {
                         // use cache?
