@@ -13,57 +13,102 @@
 
 define('io.ox/core/boot/load', [
     'themes',
+    'gettext',
+    'io.ox/core/extensions',
+    'io.ox/core/boot/config',
     'io.ox/core/boot/util',
+    'io.ox/core/session',
     'io.ox/core/http',
     'settings!io.ox/core',
-    'settings!io.ox/mail',
     'io.ox/core/capabilities',
     'io.ox/core/manifests',
     'io.ox/core/sockets',
     'io.ox/core/moment'
-], function (themes, util, http, coreSettings, mailSettings, capabilities, manifests, socket) {
+], function (themes, gettext, ext, config, util, session, http, coreSettings, capabilities, manifests, socket) {
 
     'use strict';
 
-    return function load() {
+    ext.point('io.ox/core/boot/load').extend([{
+        id: 'user_config',
+        // wait for user config
+        run: function () { return config.user(); }
+    }, {
+        id: 'i18n',
+        run: function (baton) {
+            // apply session data (again) & page title
+            if (baton.sessionData) session.set(baton.sessionData);
+            ox.trigger('change:document:title');
+            // load UI
+            util.debug('Load UI > load i18n plugins and set current language', ox.language);
 
-        // remove unnecessary stuff
-        util.cleanUp();
+            // signin phase is over (important for gettext)
+            ox.signin = false;
 
-        prefetch();
-        setupSockets();
-        loadUserTheme();
+            // we have to clear the device function cache or there might be invalid return values, like for example wrong language data.(see Bug 51405)
+            _.device.cache = {};
+            // make sure we have loaded precore.js now
+            return $.when(
+                require([ox.base + '/precore.js']),
+                gettext.setLanguage(ox.language),
+                manifests.manager.loadPluginsFor('i18n')
+            ).then(function () {
+                util.debug('Load UI > current language and i18n plugins DONE.');
+                gettext.enable();
+            });
+        }
+    }, {
+        id: 'warnings',
+        run: function () {
+            // don't block
+            require(['io.ox/core/boot/warning']).then(function () {
+                ext.point('io.ox/core/boot/warning').invoke('draw');
+            });
+        }
+    }, {
+        id: 'load',
+        run: function () {
+            util.restore();
 
-        ox.once('boot:done', function () {
-            // clear password (now); if cleared or set to "******" too early,
-            // Chrome won't store anything or use that dummay value (see bug 36950)
-            $('#io-ox-login-password').val('');
-            // final step: launch
-            require('io.ox/core/main').launch();
-        });
-    };
+            // remove unnecessary stuff
+            util.cleanUp();
+            require(['settings!io.ox/mail']).then(prefetch);
+            setupSockets();
+            //"core" namespace has now a very similar timing to "io.ox/core/main" namespace
+            //the only difference is, "core" plugins are loaded completely before
+            //"io.ox/core/main" plugins
+            var loadCore = manifests.manager.loadPluginsFor('core').then(function () {
+                return require(['io.ox/core/main']);
+            });
+            return $.when(loadCore, loadUserTheme()).then(function success(core) {
+                util.debug('DONE!');
+                ox.trigger('boot:done');
+
+                // clear password (now); if cleared or set to "******" too early,
+                // Chrome won't store anything or use that dummay value (see bug 36950)
+                $('#io-ox-login-password').val('');
+                // final step: launch
+                core.launch();
+            }, function fail(e) {
+                console.error('Cannot launch core!', e);
+                ox.trigger('boot:fail');
+            });
+        }
+    }]);
 
     function loadUserTheme() {
         // we have to clear the device function cache or there might be invalid return values, like for example wrong language data.(see Bug 51405)
         _.device.cache = {};
         var theme = _.sanitize.option(_.url.hash('theme')) || coreSettings.get('theme') || 'default',
-            loadTheme = themes.set(theme),
-            //"core" namespace has now a very similar timing to "io.ox/core/main" namespace
-            //the only difference is, "core" plugins are loaded completely before
-            //"io.ox/core/main" plugins
-            loadCore = manifests.manager.loadPluginsFor('core').then(function () {
-                return require(['io.ox/core/main']);
-            });
+            loadTheme = themes.set(theme);
 
         util.debug('Load UI > require [core/main] and set theme', theme);
 
-        $.when(loadCore, loadTheme).then(
-            launch.bind(null, loadCore),
-            loadDefaultTheme.bind(null, theme, loadCore, loadTheme)
+        return loadTheme.catch(
+            loadDefaultTheme.bind(null, theme)
         );
     }
 
-    function loadDefaultTheme(theme, loadCore, loadTheme) {
+    function loadDefaultTheme(theme) {
 
         function fail() {
             console.error('Could not load default theme');
@@ -73,34 +118,16 @@ define('io.ox/core/boot/load', [
         util.debug('Loading theme failed', theme);
 
         // failed to load theme?
-        if (loadTheme.state() === 'rejected') {
-            // give up if it was the default theme
-            if (theme === 'default') return fail();
-            // otherwise try to load default theme now
-            console.error('Could not load custom theme', theme);
-            themes.set('default').then(launch.bind(null, loadCore), fail);
-        }
-    }
-
-    function launch(loadCore) {
-
-        util.debug('Load UI > launch ...');
-
-        loadCore.then(
-            function success() {
-                util.debug('DONE!');
-                ox.trigger('boot:done');
-            },
-            function fail(e) {
-                console.error('Cannot launch core!', e);
-                ox.trigger('boot:fail');
-            }
-        );
+        // give up if it was the default theme
+        if (theme === 'default') return fail();
+        // otherwise try to load default theme now
+        console.error('Could not load custom theme', theme);
+        return themes.set('default').catch(fail);
     }
 
     // greedy prefetch for mail app
     // we need to get the default all/threadedAll request out as soon as possible
-    function prefetch() {
+    function prefetch(mailSettings) {
 
         if (!capabilities.has('webmail')) return;
 
@@ -180,6 +207,39 @@ define('io.ox/core/boot/load', [
                     ox.trigger('socket:mail:new', data);
                 });
             }
+
+            if (capabilities.has('calendar')) {
+                // only call update by push max every 10s, to reduce load
+                var throttleCache = [],
+                    sendUpdateEvent = _.throttle(function () {
+                        var data = {
+                            folders: _(throttleCache).chain().pluck('folders').flatten().compact().unique().value(),
+                            invitations: _(throttleCache).chain().pluck('needsAction').flatten().compact().unique(function (event) {
+                                return event.id + '.' + event.folder + '.' + event.recurrenceId;
+                            }).value()
+                        };
+                        ox.trigger('socket:calendar:updates', data);
+                        throttleCache = [];
+                    }, 10000);
+
+                socket.on('ox:calendar:updates', function (data) {
+                    // simple event forwarding
+                    // don't log sensitive data here (data object)
+                    try {
+                        ox.websocketlog.push({
+                            timestamp: _.now(),
+                            date: moment().format('D.M.Y HH:mm:ss'),
+                            event: 'ox:calendar:updates',
+                            data: { folders: data.folders, invitations: data.needsAction }
+                        });
+                    } catch (e) {
+                        console.log(e);
+                    }
+                    throttleCache.push(data);
+                    sendUpdateEvent();
+                });
+            }
+
         });
     }
 });
