@@ -407,8 +407,8 @@ define('io.ox/core/desktop', [
                 win.floating.listenTo(model, 'change:active change:minimized', function (model) {
                     if (!win.app.dropZone) return;
                     var active = model.get('active') && !model.get('minimized');
-                    if (!active) return win.app.dropZone.remove();
-                    win.app.dropZone.include();
+                    if (!active && win.app.dropZone.remove) return win.app.dropZone.remove();
+                    if (win.app.dropZone.include) win.app.dropZone.include();
                 });
 
                 win.app.once('quit', function () { model.trigger('close'); });
@@ -573,8 +573,7 @@ define('io.ox/core/desktop', [
                         throw arguments;
                     }
                 );
-                // don't resume apps that are currently initializing
-            } else if (this.get('state') !== 'initializing' && this.has('window')) {
+            } else if (this.has('window')) {
                 // toggle app window
                 this.get('window').show();
                 this.trigger('resume', this);
@@ -770,32 +769,61 @@ define('io.ox/core/desktop', [
             return this.setSavePoints([]);
         },
 
-        removeRestorePoint: function (id) {
-            var self = this;
-            return this.getSavePoints().then(function (list) {
-                list = list || [];
+        removeRestorePoint: (function () {
+            var hash = {};
+            // Issue caused by multiple almost simultaneous removeRestorePoint calls.
+            // All callbacks work on same state of that list as getSavePoints (t3, t4...)
+            // resolves before setSavePoints of previous calls (t1, t2...). Minimal
+            // solution/workaround as backport (reduce potential impacts) by maintaining
+            // a list of deleted ids
+            function getPoint(list, id) {
                 var ids = _(list).pluck('id'),
-                    pos = _(ids).indexOf(id),
-                    point = list[pos];
-                list = list.slice();
-                if (pos > -1) {
-                    list.splice(pos, 1);
-                }
-                // if this is a point that's restored by id we need to remove it in the settings
-                if (point && point.restoreById) {
-                    var pointsById = coreSettings.get('savepoints', []);
-                    ids = _(pointsById).pluck('id');
                     pos = _(ids).indexOf(id);
-                    if (pos > -1) {
-                        pointsById.splice(pos, 1);
-                        coreSettings.set('savepoints', pointsById).save();
-                    }
-                }
-                return self.setSavePoints(list).then(function () {
-                    return list;
+                return list[pos];
+            }
+
+            function cleanupHash(list) {
+                _(hash).each(function (value, id) {
+                    if (getPoint(list, id)) return;
+                    // point finally removed
+                    delete hash[id];
                 });
-            });
-        },
+            }
+
+            return function (id) {
+                var self = this;
+                hash[id] = true;
+                return this.getSavePoints().then(function (list) {
+                    list = (list || []).slice();
+                    // remove already removed ones from 'removeHash'
+                    cleanupHash(list);
+
+                    var ids = _(list).pluck('id');
+                    // loop all 'to be removed' ones
+                    _(hash).each(function (value, id) {
+                        var pos = _(ids).indexOf(id),
+                            point = list[pos];
+                        if (pos > -1) {
+                            list.splice(pos, 1);
+                        }
+                        // if this is a point that's restored by id we need to remove it in the settings
+                        if (point && point.restoreById) {
+                            var pointsById = coreSettings.get('savepoints', []);
+                            ids = _(pointsById).pluck('id');
+                            pos = _(ids).indexOf(id);
+                            if (pos > -1) {
+                                pointsById.splice(pos, 1);
+                                coreSettings.set('savepoints', pointsById).save();
+                            }
+                        }
+
+                    });
+                    return self.setSavePoints(list).then(function () {
+                        return list;
+                    });
+                });
+            };
+        })(),
 
         restore: function () {
             var self = this;
@@ -822,6 +850,7 @@ define('io.ox/core/desktop', [
                                 }
                                 win.listenToOnce(model, 'lazyload', function () {
                                     var oldId = obj.id;
+                                    obj = _.clone(obj);
                                     if (app.options.floating) {
                                         // copy app options over to window model
                                         model.set(_(app.options).pick('closable', 'displayStyle', 'size', 'taskbarIcon', 'title'));
@@ -865,6 +894,7 @@ define('io.ox/core/desktop', [
                                 });
                                 return $.when();
                             }
+                            var oldId = obj.id;
                             return app.launch().then(function () {
                                 // update unique id
                                 obj.id = this.get('uniqueID');
@@ -874,6 +904,12 @@ define('io.ox/core/desktop', [
                                         app.set('restored', true);
                                     });
                                 }
+                            }).fail(function (e) {
+                                if (!e || e.code !== 'MSG-0032') return;
+                                // restoreById-savepoint after draft got deleted
+                                _.delay(function () {
+                                    ox.ui.App.removeRestorePoint(oldId);
+                                });
                             });
                         });
                     })
@@ -903,6 +939,11 @@ define('io.ox/core/desktop', [
             return false;
         },
 
+        isCurrent: function (app) {
+            var current = ox.ui.App.getCurrentApp();
+            return !!(current && current.get('name') === (_.isString(app) ? app : app.model.get('name')));
+        },
+
         getCurrentApp: function () {
             return currentWindow !== null ? currentWindow.app : null;
         },
@@ -1847,6 +1888,16 @@ define('io.ox/core/desktop', [
         return def;
     };
 
+    // retrigger jquery events to allow listenTo event registration
+    ox.dom = _.extend({
+        retrigger: function (e) { ox.dom.trigger(e.type, e); }
+    }, ox.dom, Backbone.Events);
+    $(document).on('dragover', ox.dom.retrigger);
+    $(document).on('mouseout', ox.dom.retrigger);
+    $(document).on('dragleave', ox.dom.retrigger);
+    $(document).on('drop', ox.dom.retrigger);
+    $(window).on('resize', ox.dom.retrigger);
+
     apps.on('resume', function (app) {
         adaptiveLoader.stop();
         adaptiveLoader.listen(app.get('name'));
