@@ -13,18 +13,23 @@
 
 define('io.ox/core/download', ['io.ox/files/api', 'io.ox/mail/api', 'io.ox/core/yell'], function (api, mailAPI, yell) {
 
+    /* global blankshield:true */
+
     'use strict';
 
     // export global callback; used by server response
     window.callback_yell = yell;
 
     function map(o) {
-        return { id: o.id, folder_id: o.folder_id };
+        return { id: o.id, folder_id: o.folder || o.folder_id };
     }
 
     // simple iframe download (see bug 29276)
     // window.open(url); might leave open tabs or provoke popup-blocker
     // window.location.assign(url); has a weird impact on ongoing uploads (see Bug 27420)
+    //
+    // Note: This does not work for iOS as Safari will show the content of the download in the iframe as a preview
+    // for the most known file types like MS Office, pictures, plain text, pdf, etc.!
     function iframe(url) {
         url += (url.indexOf('?') === -1 ? '?' : '&') + 'callback=yell';
         $('#tmp').append(
@@ -32,21 +37,21 @@ define('io.ox/core/download', ['io.ox/files/api', 'io.ox/mail/api', 'io.ox/core/
         );
     }
 
-    // works across all browsers for multiple items (see bug 29408)
+    // works across all browsers (except mobile safari) for multiple items (see bug 29408)
     function form(options) {
 
         options = options || {};
 
         var name = _.uniqueId('iframe'),
-            form = $('<form>', { action: options.url, method: 'post', target: name });
-
-        $('#tmp').append(
-            $('<iframe>', { src: 'blank.html', name: name, 'class': 'hidden download-frame' }),
-            form.append(
+            iframe = $('<iframe>', { src: 'blank.html', name: name, 'class': 'hidden download-frame' }),
+            form = $('<form>', { action: options.url, method: 'post', target: name }).append(
                 $('<input type="hidden" name="body" value="">').val(options.body)
-            )
-        );
+            );
 
+        // except for iOS we use a hidden iframe
+        // iOS will open the form in a new window/tab
+        if (!_.device('ios')) $('#tmp').append(iframe);
+        $('#tmp').append(form);
         form.submit();
     }
 
@@ -56,8 +61,17 @@ define('io.ox/core/download', ['io.ox/files/api', 'io.ox/mail/api', 'io.ox/core/
         url: iframe,
         multiple: form,
 
+        // actually only for ios
+        window: function (url) {
+            return blankshield.open(url, '_blank');
+        },
+
         // download single file
         file: function (options) {
+
+            // on iOS we need a new window, so open this right now
+            var win = _.device('ios') && this.window('blank.html');
+
             api.get(options).done(function (file) {
                 if (options.version) {
                     file = _.extend({}, file, { version: options.version });
@@ -66,7 +80,28 @@ define('io.ox/core/download', ['io.ox/files/api', 'io.ox/mail/api', 'io.ox/core/
                     file = _.extend(file, { filename: options.filename });
                 }
                 var url = api.getUrl(file, 'download', { params: options.params });
-                iframe(url);
+                if (_.device('ios')) {
+                    win.location = url;
+                } else {
+                    iframe(url);
+                }
+            });
+        },
+
+        // export list of ids or a complete folder
+        exported: function (options) {
+            if (!/^(VCARD|ICAL|CSV)$/i.test(options.format)) return;
+            var opt = _.extend({ include: true }, options),
+                isSelective = !opt.folder && opt.list;
+            form({
+                url: ox.apiRoot + '/export?' +
+                    'action=' + opt.format.toUpperCase() +
+                    (isSelective ? '' : '&folder=' + opt.folder) +
+                    '&export_dlists=' + (opt.include ? 'true' : 'false') +
+                    '&content_disposition=attachment' +
+                    (opt.columns && opt.format.toUpperCase() === 'CSV' ? '&columns=' + opt.columns : '') +
+                    '&session=' + ox.session,
+                body: (isSelective ? JSON.stringify(_.map(opt.list, map)) : '')
             });
         },
 
