@@ -55,7 +55,7 @@ define('io.ox/core/folder/actions/rename', [
         )
         .build(function () {
             this.getContentNode().append(
-                $('<form role="form">').append(
+                $('<form>').append(
                     $('<input class="form-control" type="text">').attr('placeholder', gt('Folder name')).val(model.get('title'))
                 )
             );
