@@ -378,7 +378,6 @@ define('io.ox/core/folder/api', [
                 var data = this.models[id].toJSON();
                 this.models[id] = null;
                 delete this.models[id];
-                api.trigger('before:remove', data);
                 api.trigger('remove', id, data);
                 api.trigger('remove:' + id, data);
                 api.trigger('remove:' + data.module, data);
@@ -462,7 +461,7 @@ define('io.ox/core/folder/api', [
         });
     }
 
-    if (capabilities.has('edit_public_folders')) {
+    if (!capabilities.has('guest') && capabilities.has('edit_public_folders')) {
         pool.addModel({
             folder_id: '1',
             id: 'cal://0/allPublic',
@@ -857,7 +856,6 @@ define('io.ox/core/folder/api', [
     }
 
     function flat(options) {
-
         options = _.extend({ module: undefined, cache: true }, options);
         if (options.module === 'calendar') options.module = 'event';
 
@@ -881,6 +879,8 @@ define('io.ox/core/folder/api', [
             return $.when(cached);
         }
 
+        api.trigger('before:flat:' + options.module);
+
         return http.GET({
             module: 'folders',
             appendColumns: true,
@@ -954,6 +954,8 @@ define('io.ox/core/folder/api', [
             collectionId = getFlatCollectionId(module, 'sharing');
             sharing = processListResponse(collectionId, sharing);
             pool.addCollection(collectionId, sections.sharing = sharing, { reset: true });
+
+            api.trigger('after:flat:' + options.module);
             // done
             return sections;
         });
@@ -993,7 +995,16 @@ define('io.ox/core/folder/api', [
                     return list(model.get('folder_id'), { cache: false })
                             .then(function () {
                                 pool.getCollection(model.get('folder_id')).sort();
-                                if ('title' in changes) api.trigger('after:rename', id, model.toJSON());
+
+                                if ('title' in changes) {
+
+                                    // it's possible that external storage adapter rename a folder again after a user-rename (e.g. #56749), depending on the result update drive icon/list view
+                                    var renamedByResponse = _.propertyOf(changes)('title') !== model.get('title');
+                                    if (renamedByResponse) api.trigger('rename', id, model.toJSON());
+
+                                    api.trigger('after:rename', id, model.toJSON());
+                                }
+
                                 return newId;
                             });
                 }
