@@ -349,12 +349,18 @@ define('io.ox/core/folder/contextmenu', [
         //
         exportData: (function () {
 
-            function handler(e) {
+            function exportDialog(e) {
                 require(['io.ox/core/export'], function (exportDialog) {
                     exportDialog.open(e.data.baton.data.module, { folder: e.data.baton.data.id });
                 });
             }
 
+            function download(e) {
+                require(['io.ox/core/download'], function (download) {
+                    download.exported({ folder: e.data.baton.data.id, format: 'ical' });
+                });
+            }
+
             return function (baton) {
 
                 if (_.device('ios || android')) return;
@@ -362,6 +368,9 @@ define('io.ox/core/folder/contextmenu', [
                 if (baton.data.total === 0) return;
                 if (!_.isNumber(baton.data.total) && baton.data.total !== null) return;
 
+                var handler = exportDialog;
+                if (baton.data.module === 'calendar') handler = download;
+
                 contextUtils.addLink(this, {
                     action: 'export',
                     data: { baton: baton },
@@ -575,7 +584,7 @@ define('io.ox/core/folder/contextmenu', [
 
                 var listItem, container = this.parent();
 
-                this.append(listItem = $('<li role="presentation">'));
+                this.append(listItem = $('<li role="presentation" class="io-ox-calendar-color-picker-container">'));
 
                 require(['io.ox/calendar/color-picker', 'io.ox/calendar/util'], function (ColorPicker, calendarUtil) {
                     listItem.append(
