@@ -14,6 +14,7 @@
 define('io.ox/core/folder/tree', [
     'io.ox/backbone/disposable',
     'io.ox/backbone/mini-views/dropdown',
+    'io.ox/backbone/mini-views/contextmenu-utils',
     'io.ox/core/folder/selection',
     'io.ox/core/folder/api',
     'io.ox/core/extensions',
@@ -21,20 +22,24 @@ define('io.ox/core/folder/tree', [
     'settings!io.ox/core',
     'gettext!io.ox/core',
     'io.ox/core/folder/favorites',
+    'io.ox/files/favorites',
     'io.ox/core/folder/extensions'
-], function (DisposableView, Dropdown, Selection, api, ext, a11y, settings, gt) {
+], function (DisposableView, Dropdown, ContextMenuUtils, Selection, api, ext, a11y, settings, gt) {
 
     'use strict';
 
     var TreeView = DisposableView.extend({
 
+        attributes: { role: 'complementary' },
+
         className: 'folder-tree',
 
         events: {
             'click .contextmenu-control': 'onToggleContextMenu',
-            'contextmenu .folder.selectable[aria-haspopup="true"], .contextmenu-control': 'onContextMenu',
+            'contextmenu .folder.selectable[aria-haspopup="true"]': 'onContextMenu',
             'keydown .folder.selectable[aria-haspopup="true"]': 'onKeydownMenuKeys',
-            'keydown .folder.selectable': 'onKeydown'
+            'keydown .folder.selectable': 'onKeydown',
+            'click .folder.selectable.selected': 'onClick'
         },
 
         initialize: function (options) {
@@ -65,6 +70,7 @@ define('io.ox/core/folder/tree', [
 
             this.$el.data('view', this);
             this.$container = $('<ul class="tree-container f6-target" role="tree">').attr('id', this.id);
+            this.$el.attr('aria-label', gt('Folders'));
 
             this.$dropdownMenu = $();
             this.options = options;
@@ -87,6 +93,12 @@ define('io.ox/core/folder/tree', [
             this.trigger('appear:' + id, node);
         },
 
+        // See Bug: 54812 (Note: This should not be necessary, but node does not get focus otherwise)
+        onClick: function (e) {
+            if ($(document.activeElement).is('.folder.selectable.selected')) return;
+            $(e.currentTarget).focus();
+        },
+
         // counter-part
         onAppear: function (id, handler) {
             var node = this.getNodeView(id);
@@ -102,6 +114,7 @@ define('io.ox/core/folder/tree', [
             this.onAppear(id, function () {
                 // defer selection; might be too fast otherwise
                 _.defer(this.selection.set.bind(this.selection, id));
+                this.trigger('afterAppear');
             });
         },
 
@@ -148,12 +161,16 @@ define('io.ox/core/folder/tree', [
             if (result !== undefined) return result;
             // other folders
             var module = model.get('module');
+            if (module === 'event') module = 'calendar';
             return module === this.module || (this.module === 'mail' && (/^default\d+(\W|$)/i).test(model.id));
         },
 
         getOpenFolders: function () {
             return _(this.$el.find('.folder.open')).chain()
-                .map(function (node) { return $(node).attr('data-id'); })
+                .map(function (node) {
+                    var namespace = $(node).attr('data-namespace') ? $(node).attr('data-namespace') + ':' : '';
+                    return namespace + $(node).attr('data-id');
+                })
                 .uniq().value().sort();
         },
 
@@ -168,20 +185,24 @@ define('io.ox/core/folder/tree', [
             if (options.parent.folder === 'virtual/standard') {
                 options.icons = true;
             }
+            if (options.parent.folder === 'virtual/favorites/infostore') {
+                options.inFavorites = true;
+            }
+
             return options;
         },
 
-        toggleContextMenu: function (target, top, left) {
+        toggleContextMenu: function (pos) {
 
             // return early on close
             var isOpen = this.dropdown.$el.hasClass('open');
             if (isOpen || _.device('smartphone')) return;
-            if (!target.is('a.contextmenu-control')) target = target.find('.contextmenu-control').first();
+            if (!pos.target.is('a.contextmenu-control')) pos.target = pos.target.find('.contextmenu-control').first();
 
             _.defer(function () {
 
-                this.$dropdownMenu.css({ top: top, left: left, bottom: 'auto' }).empty().busy();
-                this.dropdown.$toggle = target;
+                this.$dropdownMenu.css({ top: pos.top, left: pos.left, bottom: 'auto' }).empty().busy();
+                this.dropdown.$toggle = pos.target;
                 this.$dropdownToggle.dropdown('toggle');
 
             }.bind(this));
@@ -195,7 +216,7 @@ define('io.ox/core/folder/tree', [
                 left = offset.left + target.outerWidth() + 7;
 
             target.data('preventFocus', true);
-            this.toggleContextMenu(target, top, left);
+            this.toggleContextMenu({ target: target, top: top, left: left });
         },
 
         onKeydown: function (e) {
@@ -210,6 +231,7 @@ define('io.ox/core/folder/tree', [
         },
 
         onKeydownMenuKeys: function (e) {
+            ContextMenuUtils.macOSKeyboardHandler(e);
             // Needed for a11y, shift + F10 and the menu key open the contextmenu
             if (e.type !== 'keydown') return;
 
@@ -219,9 +241,9 @@ define('io.ox/core/folder/tree', [
                 this.focus = /38/.test(e.which) ? 'li:last > a' : 'li:first > a';
             }
 
-            if (shiftF10 || menuKey) {
-                // e.preventDefault() is needed here to surpress browser menu
-                e.preventDefault();
+            if (shiftF10 && e.isKeyboardEvent) {
+                // e.isKeyboardEvent will be true for Shift-F10 triggered context menus on macOS
+                // other browsers will just trigger contextmenu events
                 this.onContextMenu(e);
             }
         },
@@ -230,16 +252,7 @@ define('io.ox/core/folder/tree', [
             // clicks bubbles. right-click not
             // DO NOT ADD e.preventDefault() HERE (see bug 42409)
             e.stopPropagation();
-            var target = $(e.currentTarget).data('fixed', true), top = e.pageY - 20, left = e.pageX + 30;
-            if (target.is('.contextmenu-control')) {
-                top = target.offset().top;
-                left = target.offset().left + 40;
-                target.removeData('fixed');
-                // need prevent default here, so there is no second (browser) contextmenu via the control
-                // Bug 42409 still fixed
-                e.preventDefault();
-            }
-            this.toggleContextMenu(target, top, left);
+            this.toggleContextMenu(ContextMenuUtils.positionForEvent(e));
         },
 
         getContextMenuId: function (id) {
@@ -252,10 +265,11 @@ define('io.ox/core/folder/tree', [
                 module = this.module,
                 ul = this.$dropdownMenu.empty(),
                 point = this.getContextMenuId(contextmenu),
-                view = this;
+                view = this,
+                favorite = this.selection.get('data-favorite');
             // get folder data and redraw
             api.get(id).done(function (data) {
-                var baton = new ext.Baton({ app: app, data: data, view: view, module: module });
+                var baton = new ext.Baton({ app: app, data: data, view: view, module: module, favorite: favorite });
                 ext.point(point).invoke('draw', ul, baton);
                 if (_.device('smartphone')) {
                     ul.append(
@@ -304,7 +318,7 @@ define('io.ox/core/folder/tree', [
             }
 
             function fixFocus() {
-                this.dropdown.$toggle.parents('li').focus();
+                this.dropdown.$toggle.parents('li').first().focus();
             }
 
             return function () {
