@@ -11,7 +11,7 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/core/util', ['io.ox/core/extensions', 'settings!io.ox/core'], function (ext, settings) {
+define('io.ox/core/util', ['io.ox/core/extensions', 'settings!io.ox/core', 'static/3rd.party/purify.min.js'], function (ext, settings, DOMPurify) {
 
     'use strict';
 
@@ -73,6 +73,9 @@ define('io.ox/core/util', ['io.ox/core/extensions', 'settings!io.ox/core'], func
                 user_id: options.user_id
             };
 
+            // add contact data if available, (extended entities for attendees for example)
+            if (options.contact) halo.contact = options.contact;
+
             if (data && data.nohalo) options.$el = $('<span>');
 
             var baton = new ext.Baton({ data: data || {}, halo: halo, html: options.html });
@@ -129,11 +132,26 @@ define('io.ox/core/util', ['io.ox/core/extensions', 'settings!io.ox/core'], func
 
         // detect URLs in plain text
         urlify: function (text) {
-            return text.replace(regUrl, function (url) {
+            text = (text || '').replace(regUrl, function (url) {
                 var fix = this.fixUrlSuffix(url);
                 // soft-break long words (like long URLs)
-                return '<a href="' + fix.url + '" target="_blank" rel="noopener">' + that.breakableHTML(fix.url) + '</a>' + fix.suffix;
+                var node = $('<a target="_blank" rel="noopener">').attr('href', encodeURI(decodeURI(fix.url))).append(that.breakableHTML(fix.url));
+                return node.prop('outerHTML') + fix.suffix;
             }.bind(this));
+
+            text = DOMPurify.sanitize(text, { ALLOW_TAGS: ['a', 'wbr'], ALLOWED_ATTR: ['target', 'rel', 'href'], SAFE_FOR_JQUERY: true });
+            text = that.injectAttribute(text, 'a', 'rel', 'noopener');
+            return text;
+
+        },
+
+        injectAttribute: function (text, tagName, attr, value) {
+            var tmp = document.createElement('div');
+            tmp.innerHTML = text;
+            _(tmp.getElementsByTagName(tagName)).each(function (node) {
+                node.setAttribute(attr, value);
+            });
+            return tmp.innerHTML;
         },
 
         // split long character sequences
