@@ -18,9 +18,10 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
     'io.ox/core/util',
     'io.ox/mail/util',
     'io.ox/core/capabilities',
+    'io.ox/core/viewer/util',
     'settings!io.ox/core',
     'gettext!io.ox/core/viewer'
-], function (PanelBaseView, Ext, folderAPI, UserAPI, util, mailUtil, capabilities, settings, gt) {
+], function (PanelBaseView, Ext, folderAPI, UserAPI, util, mailUtil, capabilities, ViewerUtil, settings, gt) {
 
     'use strict';
 
@@ -45,8 +46,8 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
         var name = model.getDisplayName() || '-';
         var disableLink = options.disableLink || false;
 
-        //fix for 53324
-        if (model.get('source') !== 'drive') return $.txt(name);
+        //fix for 53324, 58378, 58894
+        if (!model.isDriveItem()) return $.txt(name);
 
         // fix for 56070
         if (disableLink) return $.txt(name);
@@ -57,6 +58,14 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
             .text(name);
     }
 
+    function renderDateString(model) {
+        var modified = model.get('last_modified');
+        var isToday = moment().isSame(moment(modified), 'day');
+        var dateString = modified ? moment(modified).format(isToday ? 'LT' : 'l LT') : '-';
+
+        return dateString;
+    }
+
     Ext.point('io.ox/core/viewer/sidebar/fileinfo').extend({
         index: 100,
         id: 'fileinfo',
@@ -64,17 +73,13 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
 
             if (!baton.model) return;
 
-            var model = baton.model,
-                options = baton.options || {},
-                size = model.get('file_size'),
-                sizeString = (_.isNumber(size)) ? _.filesize(size) : '-',
-                modifiedBy = model.get('modified_by'),
-                modified = model.get('last_modified'),
-                isToday = moment().isSame(moment(modified), 'day'),
-                dateString = modified ? moment(modified).format(isToday ? 'LT' : 'l LT') : '-',
-                folder_id = model.get('folder_id'),
-                dl = $('<dl>'),
-                isAttachmentView = !_.isEmpty(model.get('com.openexchange.file.storage.mail.mailMetadata'));
+            var model = baton.model;
+            var options = baton.options || {};
+            var modifiedBy = model.get('modified_by');
+            var dateString = renderDateString(model);
+            var folder_id = model.get('folder_id');
+            var dl = $('<dl>');
+            var isAttachmentView = !_.isEmpty(model.get('com.openexchange.file.storage.mail.mailMetadata'));
 
             dl.append(
                 // filename
@@ -84,11 +89,11 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
                 ),
                 // size
                 $('<dt>').text(gt('Size')),
-                $('<dd class="size">').text(sizeString)
+                $('<dd class="size">').text(ViewerUtil.renderItemSize(model))
             );
             if (!isAttachmentView) {
                 dl.append(
-                     // modified
+                    // modified
                     $('<dt>').text(gt('Modified')),
                     $('<dd class="modified">').append(
                         $('<span class="modifiedAt">').text(dateString),
@@ -219,7 +224,7 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
             //#. File and folder details
             this.setPanelHeader(gt('Details'));
             // attach event handlers
-            this.listenTo(this.model, 'change:cid change:filename change:file_size change:last_modified change:folder_id change:object_permissions change:permissions', this.render);
+            this.listenTo(this.model, 'change:cid change:filename change:title change:com.openexchange.file.sanitizedFilename change:file_size change:last_modified change:folder_id change:object_permissions change:permissions', this.render);
             this.on('dispose', this.disposeView.bind(this));
         },
 
@@ -234,9 +239,7 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
             // only draw if needed
             if (this.closable && this.$('.sidebar-panel-heading .close').length === 0) {
                 this.$('.sidebar-panel-heading').prepend(
-                    $('<button type="button" class="close pull-right">')
-                    .attr('aria-label', gt('Hide details'))
-                    .append('<span aria-hidden="true">&times;</span></button>')
+                    $('<button type="button" class="close pull-right">').attr('title', gt('Hide details')).append('<i class="fa fa-times" aria-hidden="true">')
                 );
             }
 
