@@ -136,34 +136,17 @@ define('io.ox/mail/accounts/settings', [
     });
 
     ext.point('io.ox/mail/add-account/preselect').extend({
-        id: 'dsc',
-        before: 'oauth',
-        draw: function (baton) {
-            if (!mailSettings.get('dsc/enabled')) {
-                // normal mode for all setups not using DSC
-                return;
-            }
-            // show classic wizard for DSC setups, bypass oauth accounts
-            ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
-            _.defer(function () {
-                baton.popup.getFooter().find('[data-action="add"]').show();
-            }, 1000);
-
-            baton.stopPropagation();
-        }
-
-    }, {
         id: 'oauth',
         index: 100,
         draw: function (baton) {
             var $el = this;
-            $el.empty().addClass('mail-account-dialog');
             require(['io.ox/oauth/keychain', 'io.ox/oauth/backbone']).then(function (oauthAPI, OAuth) {
                 var mailServices = new Backbone.Collection(oauthAPI.services.filter(function (service) {
-                        return _(service.get('availableScopes')).contains('mail') &&
+                        return service.canAdd({ scopes: ['mail'] }) &&
                             oauthAPI.accounts.forService(service.id, { scope: 'mail' }).map(function (account) {
                                 return account.id;
-                            }).reduce(function (acc, oauthId) {
+                            })
+                            .reduce(function (acc, oauthId) {
                                 // make sure, no mail account using this oauth-account exists
                                 return acc && !_(api.cache).chain()
                                     .values()
@@ -173,7 +156,7 @@ define('io.ox/mail/accounts/settings', [
                                     .any(oauthId)
                                     .value();
                             }, true);
-                    })), list = new OAuth.Views.ServicesListView({ collection: mailServices, model: { mailService: true } });
+                    })), list = new OAuth.Views.ServicesListView({ collection: mailServices });
 
                 if (mailServices.length === 0) {
                     baton.popup.getFooter().find('[data-action="add"]').show();
@@ -181,14 +164,17 @@ define('io.ox/mail/accounts/settings', [
                     ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
                     return;
                 }
+                // Invoke extension point for custom predefined non-oauth accounts
+                ext.point('io.ox/mail/add-account/predefined').invoke('customize', this, mailServices);
+
                 mailServices.push({
                     id: 'mailwizard',
                     type: 'wizard',
-                    displayName: gt('Add other mail account')
+                    displayName: gt('Other')
                 });
 
                 $el.append(
-                    $('<label>').text(gt('Please choose your mail account provider.')),
+                    $('<label>').text(gt('Please select your mail account provider')),
                     list.render().$el,
                     createUnifiedMailboxInput()
                 );
@@ -196,15 +182,10 @@ define('io.ox/mail/accounts/settings', [
                 a11y.getTabbable($el).first().focus();
 
                 list.listenTo(list, 'select', function (service) {
-                    if (service.id === 'mailwizard') return;
-
-                    var account = oauthAPI.accounts.forService(service.id).filter(function (account) {
-                        return !account.hasScopes('mail');
-                    })[0] || new OAuth.Account.Model({
+                    if (service.get('type') === 'wizard') return;
+                    var account = new OAuth.Account.Model({
                         serviceId: service.id,
-                        //#. %1$s is the display name of the account
-                        //#. e.g. My Xing account
-                        displayName: gt('My %1$s account', service.get('displayName'))
+                        displayName: oauthAPI.chooseDisplayName(service)
                     });
 
                     account.enableScopes('mail').save().then(function () {
@@ -223,15 +204,13 @@ define('io.ox/mail/accounts/settings', [
 
                             validateMailaccount(data, baton.popup, def);
                             return def;
-                        }).then(function () {
-                            oauthAPI.accounts.add(account, { merge: true });
-                        }, notifications.yell).always(function () {
+                        }).fail(notifications.yell).always(function () {
                             baton.popup.idle();
                         });
                     });
                 });
 
-                list.listenTo(list, 'select:mailwizard', function () {
+                list.listenTo(list, 'select:wizard', function () {
                     baton.popup.getFooter().find('[data-action="add"]').show();
                     // invoke wizard
                     var data = {};
@@ -380,6 +359,9 @@ define('io.ox/mail/accounts/settings', [
                             function saveFail(response) {
                                 popup.close();
                                 failDialog(response.error);
+                                // error is already shown to the user, don't yell
+                                response.handled = true;
+                                def.reject(response);
                             }
                         );
                     } else if (options && options.onValidationError) {
@@ -492,7 +474,7 @@ define('io.ox/mail/accounts/settings', [
                 })
                 .addPrimaryButton('add', gt('Add'), 'add')
                 .addButton('cancel', gt('Cancel'), 'cancel')
-                .addAlternativeButton('skip', gt('Manual'), 'skip')
+                //.addAlternativeButton('skip', gt('Manual'), 'skip')
                 .on('add', function () {
 
                     var content = this.getContentNode(),
@@ -510,19 +492,19 @@ define('io.ox/mail/accounts/settings', [
                         this.idle();
                     }
                 })
-                .on('skip', function () {
-                    // primary address needs to be provided, why? fails without
-                    args.data = { primary_address: this.getContentNode().find('.add-mail-account-address').val() };
+                // .on('skip', function () {
+                //     // primary address needs to be provided, why? fails without
+                //     args.data = { primary_address: this.getContentNode().find('.add-mail-account-address').val() };
 
-                    if (this.getContentNode().find('input[name="unified_inbox_enabled"]').length > 0) {
-                        args.data.unified_inbox_enabled = this.getContentNode().find('input[name="unified_inbox_enabled"]').prop('checked');
-                    }
-                    // close
-                    this.close();
-                    def.reject();
-                    // jump to manual configuration
-                    createExtpointForNewAccount(args);
-                })
+                //     if (this.getContentNode().find('input[name="unified_inbox_enabled"]').length > 0) {
+                //         args.data.unified_inbox_enabled = this.getContentNode().find('input[name="unified_inbox_enabled"]').prop('checked');
+                //     }
+                //     // close
+                //     this.close();
+                //     def.reject();
+                //     // jump to manual configuration
+                //     createExtpointForNewAccount(args);
+                // })
                 .show(function () {
                     // hide add button for now
                     this.find('[data-action="add"]').hide();
