@@ -17,14 +17,16 @@ define('io.ox/mail/actions', [
     'io.ox/core/extPatterns/links',
     'io.ox/mail/api',
     'io.ox/mail/util',
+    'io.ox/files/api',
     'io.ox/core/folder/api',
     'io.ox/core/print',
     'io.ox/core/api/account',
     'io.ox/core/notifications',
+    'io.ox/core/viewer/views/types/typesregistry',
     'settings!io.ox/mail',
     'gettext!io.ox/mail',
     'io.ox/core/capabilities'
-], function (ext, links, api, util, folderAPI, print, account, notifications, settings, gt, capabilities) {
+], function (ext, links, api, util, filesAPI, folderAPI, print, account, notifications, viewerTypes, settings, gt, capabilities) {
 
     'use strict';
 
@@ -427,6 +429,9 @@ define('io.ox/mail/actions', [
                 if (memo === false) return false;
                 // is not primary account?
                 if (!account.isPrimary(obj.folder_id)) return false;
+                // do not show in subfolders of spam folder
+                var spamfolders = account.getFoldersByType('spam').concat(account.getFoldersByType('confirmed_spam'));
+                if (spamfolders.indexOf(obj.folder_id) < 0) return false;
                 // else
                 return account.is('spam|confirmed_spam', obj.folder_id) || util.isSpam(obj);
             }, true);
@@ -452,8 +457,17 @@ define('io.ox/mail/actions', [
     });
 
     new Action('io.ox/mail/actions/view-attachment', {
-        // TODO capabilites check, files filter?
-        requires: 'some',
+        requires: function (e) {
+            if (!e.collection.has('some')) { return false; }
+
+            var attachments = _.isArray(e.baton.data) ? e.baton.data : [e.baton.data];
+            var canView = _.some(attachments, function (data) {
+                var model = new filesAPI.Model(data);
+                return viewerTypes.canView(model);
+            });
+
+            return canView;
+        },
         multiple: function (attachmentList, baton) {
             ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
                 var options = { files: attachmentList, restoreFocus: baton.restoreFocus };
@@ -855,6 +869,7 @@ define('io.ox/mail/actions', [
         id: 'view_new',
         index: 100,
         mobile: 'hi',
+        //#. used as a verb here. label of a button to view attachments
         label: gt('View'),
         ref: 'io.ox/mail/actions/view-attachment'
     }));
@@ -881,6 +896,7 @@ define('io.ox/mail/actions', [
         id: 'viewer',
         index: 600,
         mobile: 'hi',
+        //#. used as a verb here. label of a button to view attachments
         label: gt('View'),
         ref: 'io.ox/mail/actions/viewer'
     }));
