@@ -42,7 +42,7 @@ define('io.ox/mail/actions/attachmentQuota', [
                 total += fileSize;
 
                 if (quota > 0 && total > quota) {
-                    result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the maximum file size of %2$s', fileTitle, strings.fileSize(quota));
+                    result.error = gt('The file "%1$s" cannot be uploaded because it exceeds the total attachment size limit of %2$s', fileTitle, strings.fileSize(quota));
                     result.reason = 'filesize';
                     return true;
                 }
