@@ -42,8 +42,8 @@ define('io.ox/mail/api', [
             return colorLabelResort[b.color_label] - colorLabelResort[a.color_label];
         };
 
-    // model pool
-    var pool = Pool.create('mail');
+    // model pool, global for debugging
+    var pool = window.mailpool = Pool.create('mail');
 
     var fixtoccbcc = settings.get('features/fixtoccbcc'),
         showDeleted = !settings.get('features/ignoreDeleted', false),
@@ -265,31 +265,74 @@ define('io.ox/mail/api', [
         api.threads.touch(model.toJSON());
     }
 
-    function allowImages(obj) {
-        if (util.authenticity('block', obj)) return false;
-        if (!settings.get('allowHtmlImages', false)) return false;
-        if (accountAPI.is('spam|confirmed_spam|trash', obj.folder_id || obj.folder)) return false;
-        return true;
+    function getPreferredView() {
+        return settings.get('allowHtmlMessages', true) ? 'html' : 'text';
     }
 
-    function defaultView(obj) {
-        if (!settings.get('allowHtmlMessages', true)) return 'text';
-        return allowImages(obj) ? 'html' : 'noimg';
+    function getView(data) {
+        var preferred = getPreferredView();
+
+        // 'text' will always be 'text'
+        if (preferred === 'text') return 'text';
+        // never show images for failed messages
+        if (util.authenticity('block', data)) return 'noimg';
+
+        // check authenticity && whitelist
+        var isTrusted = util.authenticity('box', data) === 'trusted';
+        var isWhiteListed = util.isWhiteListed(data);
+        if (isTrusted || isWhiteListed) return preferred;
+
+        // check for general setting
+        if (!settings.get('allowHtmlImages', false)) return 'noimg';
+
+        // block images for specific folders
+        if (accountAPI.is('spam|confirmed_spam|trash', data.folder_id || data.folder)) return 'noimg';
+
+        // finally
+        return preferred;
+    }
+
+    function sanitizeAttachments(attachments) {
+        if (!_.isArray(attachments)) {
+            // make sure we always have data.attachments (see bug 58631)
+            return [{ content: '', content_type: 'text/plain', disp: 'inline', id: '1', sanitized: true, size: 0, truncated: false }];
+        }
+        // sanitize content Types (we want lowercase 'text/plain' or 'text/html')
+        // split by ; because this field might contain further unwanted data
+        return attachments.map(function (data) {
+            if (!/^text\/(plain|html)/i.test(data.content_type)) return data;
+            // only clean-up text and html; otherwise we lose data (see bug 43727)
+            data.content_type = String(data.content_type).toLowerCase().split(';')[0];
+            return sanitizer.sanitize(data);
+        });
+    }
+    function sanitizeMailData(data) {
+        data.attachments = sanitizeAttachments(data.attachments);
+
+        if (_.isArray(data.nested_msgs)) {
+            data.nested_msgs = data.nested_msgs.map(function (nested_msg) {
+                nested_msg.attachments = sanitizeAttachments(nested_msg.attachments);
+                return nested_msg;
+            });
+        }
+        return data;
     }
 
     api.get = function (obj, options) {
-
         var cid = _.isObject(obj) ? _.cid(obj) : obj,
             model = pool.get('detail').get(cid),
-            cache = options && (options.cache !== undefined) ? options.cache : true;
+            useCache = options && (options.cache !== undefined) ? options.cache : true,
+            isDefaultView = obj.view === 'noimg' || !obj.view,
+            isComplete;
 
-        if (model && util.authenticity('box', model.toJSON()) === 'trusted') obj.view = defaultView(obj) === 'text' ? 'text' : 'html';
+        if (model) {
+            isComplete = !!model.get('attachments');
+            // check for cache hit
+            if (useCache && !obj.src && isComplete && isDefaultView) return $.when(model.toJSON());
+        }
 
-        // TODO: make this smarter
-        if (cache && !obj.src && (obj.view === 'noimg' || !obj.view) && model && model.get('attachments')) return $.when(model.toJSON());
-
-        // determine default view parameter
-        if (!obj.view) obj.view = defaultView(obj);
+        // set view if needed
+        if (!obj.view) obj.view = getView(_.extend({}, obj, model && model.toJSON()));
 
         // limit default size
         obj.max_size = settings.get('maxSize/view', 1024 * 100);
@@ -303,20 +346,9 @@ define('io.ox/mail/api', [
             if (obj.src || obj.view === 'raw') return;
             // delete potential 'cid' attribute (see bug 40136); otherwise the mail gets lost
             delete data.cid;
-            if (_.isArray(data.attachments)) {
-                // sanitize content Types (we want lowercase 'text/plain' or 'text/html')
-                // split by ; because this field might contain further unwanted data
-                data.attachments.forEach(function (attachment) {
-                    if (/^text\/(plain|html)/i.test(attachment.content_type)) {
-                        // only clean-up text and html; otherwise we lose data (see bug 43727)
-                        attachment.content_type = String(attachment.content_type).toLowerCase().split(';')[0];
-                        if (sanitize) attachment = sanitizer.sanitize(attachment);
-                    }
-                });
-            } else {
-                // make sure we always have data.attachments (see bug 58631)
-                data.attachments = [{ content: '', content_type: 'text/plain', disp: 'inline', id: '1', sanitized: true, size: 0, truncated: false }];
-            }
+
+            data = sanitizeMailData(data);
+
             // either update or add model
             if (model) {
                 // if we already have a model we promote changes for threads
@@ -912,8 +944,10 @@ define('io.ox/mail/api', [
 
     function handleSpam(list, state) {
         prepareRemove(list);
-        // reset spam folder; we assume that the spam handler will move the message to the spam folder
-        resetFolderByType('spam');
+        // reset spam or inbox folder; we assume that the spam handler will move the message to the spam or inbox folder
+        if (state) resetFolderByType('spam');
+        else resetFolderByType('inbox');
+
         http.pause();
         _(list).map(function (item) {
             return http.PUT({
@@ -1157,7 +1191,7 @@ define('io.ox/mail/api', [
                 folder: obj.folder || obj.folder_id,
                 view: 'html',
                 decrypt: obj.security && obj.security.decrypted
-            }, false);
+            }, false).then(sanitizeMailData);
         } else if ('parent' in obj) {
             // nested message!?
             var id = obj.id, parent = obj.parent;
@@ -1178,7 +1212,7 @@ define('io.ox/mail/api', [
                         return false;
                     })
                     .first().value();
-            });
+            }).then(sanitizeMailData);
         }
         console.error('api.getUnmodified(). Invalid case.', obj);
         return $.Deferred().resolve(obj);
@@ -1391,7 +1425,7 @@ define('io.ox/mail/api', [
         form.append('json_0', JSON.stringify(data));
         // add files
         _(files).each(function (file, index) {
-            if (window.cordova && _.device('android')) {
+            if (file.name) {
                 form.append('file_' + index, file, file.name);
             } else {
                 form.append('file_' + index, file);
@@ -1457,7 +1491,8 @@ define('io.ox/mail/api', [
         .then(function (response) {
             var hash = {};
             _(response).each(function (item) {
-                hash[_.cid(item)] = item.text_preview || '\u00a0';
+                // please don't change the empty string fallback. if setting this to something else this causes model change events and reloading stuff.
+                hash[_.cid(item)] = item.text_preview || '';
             });
             return hash;
         });
