@@ -45,6 +45,7 @@ define('io.ox/mail/compose/model', [
                 defaultSignatureId: mailUtil.getDefaultSignature('compose'),
                 // identifier for empty signature (dropdown)
                 signatureId: '',
+                imageResizeOption: 'original',
                 csid: mailAPI.csid(),
                 vcard: settings.get('appendVcard', false) ? 1 : 0,
                 infostore_ids_saved: [],
@@ -266,6 +267,7 @@ define('io.ox/mail/compose/model', [
             this.trigger('needsync');
             var result,
                 attachmentCollection = this.get('attachments'),
+                mailAttachments = attachmentCollection.mailAttachments(),
                 content = attachmentCollection.at(0).get('content');
 
             // fix inline images
@@ -292,8 +294,21 @@ define('io.ox/mail/compose/model', [
                 'share_attachments',
                 'security'
             );
+
+            // do some cleanup on attachments
+            // remove meta from local files
+            // remove drive attachments from collection
+            var attachments = _.chain(mailAttachments)
+                .map(function (a) {
+                    return _.omit(a, 'meta');
+                })
+                .reject(function (a) {
+                    return a.source === 'drive';
+                })
+                .value();
+
             result = _.extend(result, {
-                attachments:    _(attachmentCollection.mailAttachments()).reject(function (o) { return o.source === 'drive'; }),  // get all attachments without files from drive
+                attachments:    attachments,
                 contacts_ids:   attachmentCollection.contactsIds(),      // flat cids for contacts_ids
                 infostore_ids:  attachmentCollection.driveFiles(),       // get ids only for infostore_ids
                 files:          attachmentCollection.localFiles()        // get fileObjs for locally attached files
