@@ -22,6 +22,8 @@ define('io.ox/mail/mailfilter/settings/filter/tests/util', [
 
     'use strict';
 
+    var SIZELIMITS = { 'B': 2147483648, 'K': 2097152, 'KB': 2097152, 'M': 2048, 'MB': 2048, 'G': 2, 'GB': 2 };
+
     var DropdownLinkView = mini.DropdownLinkView.extend({
         updateLabel: function () {
             this.$el.find('.dropdown-label').text(this.options.values[this.model.get(this.name)] || this.model.get(this.name));
@@ -47,12 +49,12 @@ define('io.ox/mail/mailfilter/settings/filter/tests/util', [
                 }
             });
 
-            return /^[0-9]+$/.test(number) && parseInt(number, 10) < 2147483648 && parseInt(number, 10) >= 0 && (unit === '' || _.contains(listOfUnits, unit.toUpperCase()));
+            return /^[0-9]+$/.test(number) && parseInt(number, 10) <= SIZELIMITS[unit || 'B'] && parseInt(number, 10) >= 0 && (unit === '' || _.contains(listOfUnits, unit.toUpperCase()));
         },
         onChange: function () {
             if (this.name === 'size' && this.validationForSize()) {
                 this.model.set(this.name, this.$el.val());
-            } else if (this.name === 'values' || this.name === 'headers') {
+            } else if (this.name === 'values' || this.name === 'headers' || this.name === 'source') {
                 this.model.set(this.name, [this.$el.val()]);
             } else {
                 this.model.set(this.name, this.$el.val());
@@ -122,7 +124,7 @@ define('io.ox/mail/mailfilter/settings/filter/tests/util', [
                 ),
                 $('<div class="col-sm-8">').append(
                     $('<div class="row">').append(
-                        $('<label class="col-sm-4 control-label">').attr('for', o.inputId).text(gt('Name')),
+                        $('<label class="col-sm-4 control-label">').attr('for', o.inputId).text(o.InputLabel ? o.InputLabel : gt('Name')),
                         $('<div class="first-label inline-input col-sm-8">').append(
                             new Input(o.inputOptions).render().$el,
                             o.errorView ? new mini.ErrorView({ selector: '.row' }).render().$el : []
