@@ -11,7 +11,7 @@
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define('io.ox/mail/settings/pane', [
+define.async('io.ox/mail/settings/pane', [
     'io.ox/core/extensions',
     'io.ox/backbone/views/extensible',
     'io.ox/core/capabilities',
@@ -19,9 +19,10 @@ define('io.ox/mail/settings/pane', [
     'io.ox/core/notifications',
     'io.ox/mail/mailfilter/vacationnotice/model',
     'io.ox/mail/mailfilter/autoforward/model',
+    'io.ox/core/api/mailfilter',
     'settings!io.ox/mail',
     'gettext!io.ox/mail'
-], function (ext, ExtensibleView, capabilities, util, notifications, vacationNoticeModel, autoforwardModel, settings, gt) {
+], function (ext, ExtensibleView, capabilities, util, notifications, vacationNoticeModel, autoforwardModel, mailfilter, settings, gt) {
 
     'use strict';
 
@@ -182,6 +183,13 @@ define('io.ox/mail/settings/pane', [
         }
     );
 
+    var hasVacationNoticeAction,
+        moduleReady = mailfilter.getConfig().then(function doneFilter(config) {
+            hasVacationNoticeAction = !!_(config.actioncmds).findWhere({ id: 'vacation' });
+        }, function failFilter() {
+            hasVacationNoticeAction = false;
+        });
+
     //
     // Buttons
     //
@@ -194,7 +202,7 @@ define('io.ox/mail/settings/pane', [
             index: 100,
             render: function () {
 
-                if (!capabilities.has('mailfilter_v2')) return;
+                if (!capabilities.has('mailfilter_v2') || !hasVacationNoticeAction) return;
 
                 this.append(
                     $('<button type="button" class="btn btn-default" data-action="edit-vacation-notice">')
@@ -265,7 +273,8 @@ define('io.ox/mail/settings/pane', [
             render: function () {
 
                 // we don't really need that on a smartphone (I guess) nor guests
-                if (_.device('smartphone') || capabilities.has('guest')) return;
+                // also  don't show it if diabled via server property
+                if (settings.get('ignoreSubscription', false) || _.device('smartphone') || capabilities.has('guest')) return;
 
                 this.append(
                     $('<button type="button" class="btn btn-default">')
@@ -281,4 +290,6 @@ define('io.ox/mail/settings/pane', [
             }
         }
     );
+
+    return moduleReady;
 });
