@@ -11,7 +11,7 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/mail/toolbar', [
+define.async('io.ox/mail/toolbar', [
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
@@ -20,18 +20,20 @@ define('io.ox/mail/toolbar', [
     'io.ox/core/capabilities',
     'io.ox/backbone/mini-views/dropdown',
     'io.ox/backbone/mini-views/toolbar',
+    'io.ox/core/api/mailfilter',
     'settings!io.ox/core',
     'settings!io.ox/mail',
     'gettext!io.ox/mail',
     'io.ox/mail/actions',
     'less!io.ox/mail/style',
     'io.ox/mail/folderview-extensions'
-], function (ext, links, actions, flagPicker, api, capabilities, Dropdown, Toolbar, settings, mailSettings, gt) {
+], function (ext, links, actions, flagPicker, api, capabilities, Dropdown, Toolbar, mailfilter, settings, mailSettings, gt) {
 
     'use strict';
 
     // define links for classic toolbar
-    var point = ext.point('io.ox/mail/classic-toolbar/links');
+    var point = ext.point('io.ox/mail/classic-toolbar/links'),
+        moduleReady = $.when();
 
     var meta = {
         //
@@ -257,6 +259,24 @@ define('io.ox/mail/toolbar', [
         ref: 'io.ox/mail/classic-toolbar/links'
     }));
 
+    var hasVacationNoticeAction;
+    (function () {
+        var configReady = mailfilter.getConfig().then(function doneFilter(config) {
+            hasVacationNoticeAction = !!_(config.actioncmds).findWhere({ id: 'vacation' });
+        }, function failFilter() {
+            hasVacationNoticeAction = false;
+        });
+
+        moduleReady = moduleReady.then(function () {
+            return configReady;
+        });
+
+        return function () {
+            if (!capabilities.has('mailfilter_v2') || !hasVacationNoticeAction) return;
+            this.link('vacation-notice', gt('Vacation notice'), onOpenVacationNotice);
+        };
+    })();
+
     // view dropdown
     ext.point('io.ox/mail/classic-toolbar').extend({
         id: 'view-dropdown',
@@ -266,43 +286,43 @@ define('io.ox/mail/toolbar', [
             if (_.device('smartphone')) return;
 
             //#. View is used as a noun in the toolbar. Clicking the button opens a popup with options related to the View
-            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li' })
-            .header(gt('Layout'))
-            .option('layout', 'vertical', gt('Vertical'), { radio: true });
+            var dropdown = new Dropdown({ caret: true, model: baton.app.props, label: gt('View'), tagName: 'li', attributes: { role: 'presentation' } })
+            .group(gt('Layout'))
+            .option('layout', 'vertical', gt('Vertical'), { radio: true, group: true });
             // offer compact view only on desktop
-            if (_.device('desktop')) dropdown.option('layout', 'compact', gt('Compact'), { radio: true });
-            dropdown.option('layout', 'horizontal', gt('Horizontal'), { radio: true })
-            .option('layout', 'list', gt('List'), { radio: true })
+            if (_.device('desktop')) dropdown.option('layout', 'compact', gt('Compact'), { radio: true, group: true });
+            dropdown.option('layout', 'horizontal', gt('Horizontal'), { radio: true, group: true })
+            .option('layout', 'list', gt('List'), { radio: true, group: true })
             .divider();
 
             // feature: tabbed inbox
             if (capabilities.has('mail_categories') && !_.device('smartphone')) {
                 dropdown
-                .header(gt('Inbox'))
-                .option('categories', true, gt('Use categories'))
+                .group(gt('Inbox'))
+                .option('categories', true, gt('Use categories'), { group: true })
                 //#. term is followed by a space and three dots (' …')
                 //#. the dots refer to the term 'Categories' right above this dropdown entry
                 //#. so user reads it as 'Configure Categories'
-                .link('categories-config', gt('Configure') + ' …', _.bind(onConfigureCategories, this, baton.app.props), { icon: true })
+                .link('categories-config', gt('Configure') + ' …', _.bind(onConfigureCategories, this, baton.app.props), { icon: true, group: true })
                 .divider();
             }
 
             dropdown
-            .header(gt('Options'))
-            .option('folderview', true, gt('Folder view'));
+            .group(gt('Options'))
+            .option('folderview', true, gt('Folder view'), { group: true });
             if (settings.get('selectionMode') !== 'alternative') {
-                dropdown.option('checkboxes', true, gt('Checkboxes'));
+                dropdown.option('checkboxes', true, gt('Checkboxes'), { group: true });
             }
             if (baton.app.supportsTextPreview()) {
-                dropdown.option('textPreview', true, gt('Text preview'));
+                dropdown.option('textPreview', true, gt('Text preview'), { group: true });
             }
             dropdown
-            .option('contactPictures', true, gt('Contact pictures'))
-            .option('exactDates', true, gt('Exact dates'))
-            .option('alwaysShowSize', true, gt('Message size'))
+            .option('contactPictures', true, gt('Contact pictures'), { group: true })
+            .option('exactDates', true, gt('Exact dates'), { group: true })
+            .option('alwaysShowSize', true, gt('Message size'), { group: true })
             .divider();
 
-            if (capabilities.has('mailfilter_v2')) {
+            if (capabilities.has('mailfilter_v2') && hasVacationNoticeAction) {
                 dropdown.link('vacation-notice', gt('Vacation notice'), onOpenVacationNotice);
             }
 
@@ -459,4 +479,6 @@ define('io.ox/mail/toolbar', [
             });
         }
     });
+
+    return moduleReady;
 });
