@@ -79,12 +79,10 @@ define('plugins/portal/calendar/register', [
     });
 
     function getRequestParams() {
-        var initialList = settings.get('selectedFolders');
-        if (!initialList || initialList.length === 0) initialList = [folderAPI.getDefaultFolder('calendar')];
+
         return {
             start: moment().startOf('day').valueOf(),
-            end: moment().startOf('day').add(1, 'month').valueOf(),
-            folders: initialList
+            end: moment().startOf('day').add(1, 'month').valueOf()
         };
     }
 
@@ -94,6 +92,17 @@ define('plugins/portal/calendar/register', [
 
         initialize: function (baton) {
             baton.collection = api.getCollection(getRequestParams());
+            api.on('create', function () {
+                //refresh portal
+                require(['io.ox/portal/main'], function (portal) {
+                    var portalApp = portal.getApp(),
+                        portalModel = portalApp.getWidgetCollection()._byId[baton.model.id];
+                    if (portalModel) {
+                        portalApp.refreshWidget(portalModel, 0);
+                    }
+                });
+
+            });
         },
 
         load: function (baton) {
@@ -139,7 +148,7 @@ define('plugins/portal/calendar/register', [
         },
 
         preview: function (baton) {
-            var collection = baton.collection;
+            var collection = baton.collection.filter(function (model) { return model.getTimestamp('startDate') > _.now(); });
 
             if (collection.length === 0) {
                 this.append(
@@ -150,7 +159,7 @@ define('plugins/portal/calendar/register', [
                 );
             } else {
                 this.append(new EventsView({
-                    collection: collection
+                    collection: baton.collection
                 }).render().$el);
             }
         },
@@ -159,7 +168,7 @@ define('plugins/portal/calendar/register', [
             var popup = this.busy();
             require(['io.ox/calendar/view-detail'], function (view) {
                 var model = baton.item;
-                popup.idle().append(view.draw(model, { deeplink: true }));
+                popup.idle().append(view.draw(model.toJSON(), { deeplink: true }));
             });
         },
 
