@@ -101,9 +101,8 @@ define('plugins/portal/flickr/register', [
                     });
                     // use size
                     this.addClass('photo-stream').append(
-                        $('<div class="content pointer" tabindex="1" role="button" aria-label="' + gt('Press [enter] to jump to the flicker stream.') + '">')
+                        $('<div class="content pointer" tabindex="0" role="button" class="decoration">').attr('aria-label', gt('Press [enter] to jump to the flicker stream.'))
                         .css('backgroundImage', 'url(' + url + ')')
-                        .addClass('decoration')
                     );
                 }
             }
@@ -197,9 +196,9 @@ define('plugins/portal/flickr/register', [
         model.set('candidate', true, { silent: true, validate: true });
 
         var dialog = new dialogs.ModalDialog({ async: true, width: 400 }),
-            $q = $('<input id="flickr_search" type="text" class="form-control">'),
-            $description = $('<input id="flickr_desc" type="text" class="form-control">'),
-            $method = $('<select id="flickr_option" class="form-control">').append(
+            $q = $('<input id="flickr_search" type="text" class="form-control" tabindex="0">'),
+            $description = $('<input id="flickr_desc" type="text" class="form-control" tabindex="0">'),
+            $method = $('<select id="flickr_option" class="form-control" tabindex="0">').append(
                 $('<option>').attr('value', 'flickr.photos.search').text(gt('flickr.photos.search')),
                 $('<option>').attr('value', 'flickr.people.getPublicPhotos').text(gt('flickr.people.getPublicPhotos'))
             ),
@@ -237,7 +236,8 @@ define('plugins/portal/flickr/register', [
             });
 
         dialog.on('cancel', function () {
-            if (model.has('candidate')) {
+            // if it's a new widget delete it, otherwise not
+            if (model.has('candidate') && _.isEmpty(model.get('props'))) {
                 view.removeWidget();
             }
         });
