@@ -51,7 +51,7 @@ define.async('plugins/wizards/mandatory/main', [
                 .mandatory()
                 .title(gt.format(gt('Welcome to %s'), ox.serverConfig.productName))
                 .content(gt('Before you can continue using the product, you have to enter some basic information. It will take less than a minute.'))
-                .footer($('<button class="btn pull-left">')
+                .footer($('<button type="button" class="btn pull-left">')
                     .text(gt('Back to sign in'))
                     .on('click', function () {
                         def.reject();
