@@ -11,60 +11,89 @@
  * @author Christoph Kopp <christoph.kopp@open-xchange.com>
  */
 
-define(['io.ox/mail/mailfilter/settings/filter/defaults'], function (defaults) {
+define([
+    'io.ox/core/extensions',
+    'io.ox/core/api/mailfilter',
+    'io.ox/mail/mailfilter/settings/filter/defaults',
+    'fixture!io.ox/mail/mailfilter/config.json'
+], function (ext, api, defaults, fixtureMailfilterConfig) {
 
     'use strict';
 
     describe('Mailfilter defaults', function () {
 
+        var def = $.Deferred().resolve(fixtureMailfilterConfig),
+            stub;
+
+        beforeEach(function () {
+            stub = sinon.stub(api, 'getConfig').returns(def);
+            return require(['io.ox/mail/mailfilter/settings/filter/tests/register', 'io.ox/mail/mailfilter/settings/filter/actions/register']).then(function (conditionsExtensions, actionsExtensions) {
+                conditionsExtensions.processConfig(fixtureMailfilterConfig);
+                actionsExtensions.processConfig(fixtureMailfilterConfig);
+
+                ext.point('io.ox/mail/mailfilter/tests').invoke('initialize', null, { defaults: defaults, conditionsOrder: [] });
+                ext.point('io.ox/mail/mailfilter/actions').invoke('initialize', null, { defaults: defaults, actionsOrder: [] });
+            });
+
+        });
+
+        afterEach(function () {
+            stub.restore();
+        });
+
         it('should return a object', function () {
             defaults.should.be.a('object');
         });
 
-        //tests
+        // tests
 
         it('should return a object with property tests', function () {
             defaults.should.have.a.property('tests');
         });
 
+        it('should provide defaults for nested tests', function () {
+            defaults.tests.should.have.a.property('nested');
+            defaults.tests.nested.should.be.deep.equal({ 'id': 'anyof', 'tests': [] });
+        });
+
         it('should provide defaults for test From', function () {
-            defaults.tests.should.have.a.property('From');
-            defaults.tests.From.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['From'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('from');
+            defaults.tests.from.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['From'], 'id': 'from', 'values': [''] });
         });
 
         it('should provide defaults for test any', function () {
-            defaults.tests.should.have.a.property('any');
-            defaults.tests.any.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['To', 'Cc'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('anyrecipient');
+            defaults.tests.anyrecipient.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['To', 'Cc'], 'id': 'anyrecipient', 'values': [''] });
         });
 
         it('should provide defaults for test Subject', function () {
-            defaults.tests.should.have.a.property('Subject');
-            defaults.tests.Subject.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['Subject'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('subject');
+            defaults.tests.subject.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['Subject'], 'id': 'subject', 'values': [''] });
         });
 
         it('should provide defaults for test mailingList', function () {
-            defaults.tests.should.have.a.property('mailingList');
-            defaults.tests.mailingList.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['List-Id', 'X-BeenThere', 'X-Mailinglist', 'X-Mailing-List'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('mailinglist');
+            defaults.tests.mailinglist.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['List-Id', 'X-BeenThere', 'X-Mailinglist', 'X-Mailing-List'], 'id': 'mailinglist', 'values': [''] });
         });
 
         it('should provide defaults for test To', function () {
-            defaults.tests.should.have.a.property('To');
-            defaults.tests.To.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['To'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('to');
+            defaults.tests.to.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['To'], 'id': 'to', 'values': [''] });
         });
 
         it('should provide defaults for test Cc', function () {
-            defaults.tests.should.have.a.property('Cc');
-            defaults.tests.Cc.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['Cc'], 'id': 'header', 'values': [''] });
+            defaults.tests.should.have.a.property('cc');
+            defaults.tests.cc.should.be.deep.equal({ 'comparison': 'contains', 'headers': ['Cc'], 'id': 'cc', 'values': [''] });
         });
 
-        it('should provide defaults for test cleanHeader', function () {
+        it('should provide defaults for test Header', function () {
             defaults.tests.should.have.a.property('cleanHeader');
             defaults.tests.cleanHeader.should.be.deep.equal({ 'comparison': 'matches', 'headers': [''], 'id': 'header', 'values': [''] });
         });
 
         it('should provide defaults for test envelope', function () {
             defaults.tests.should.have.a.property('envelope');
-            defaults.tests.envelope.should.be.deep.equal({ 'comparison': 'matches', 'headers': ['To'], 'id': 'envelope', 'values': [''] });
+            defaults.tests.envelope.should.be.deep.equal({ 'comparison': 'is', 'headers': ['to'], 'addresspart': 'all', 'id': 'envelope', 'values': [''] });
         });
 
         it('should provide defaults for test true', function () {
@@ -77,7 +106,17 @@ define(['io.ox/mail/mailfilter/settings/filter/defaults'], function (defaults) {
             defaults.tests.size.should.be.deep.equal({ 'comparison': 'over', 'id': 'size', 'size': '' });
         });
 
-        //actions
+        it('should provide defaults for test address', function () {
+            defaults.tests.should.have.a.property('address');
+            defaults.tests.address.should.be.deep.equal({ 'id': 'address', 'addresspart': 'all', 'comparison': 'is', 'headers': ['from'], 'values': [''] });
+        });
+
+        it('should provide defaults for test date', function () {
+            defaults.tests.should.have.a.property('date');
+            defaults.tests.date.should.be.deep.equal({ 'id': 'date', 'comparison': 'ge', 'zone': 'original', 'header': 'Date', 'datepart': 'date', 'datevalue': [] });
+        });
+
+        // actions
 
         it('should return a object with property actions', function () {
             defaults.should.have.a.property('actions');
@@ -123,5 +162,10 @@ define(['io.ox/mail/mailfilter/settings/filter/defaults'], function (defaults) {
             defaults.actions.flag.should.be.deep.equal({ 'flags': ['$cl_1'], 'id': 'addflags' });
         });
 
+        it('should provide defaults for actions copy', function () {
+            defaults.actions.should.have.a.property('copy');
+            defaults.actions.copy.should.be.deep.equal({ 'id': 'copy', 'into': 'default0/INBOX', 'copy': true });
+        });
+
     });
 });
